@@ -43,7 +43,11 @@
  * Dynamic linked library for the olsr.org olsr daemon
  */
 
- 
+#ifdef _WRS_KERNEL
+#include <vxWorks.h>
+#include <sockLib.h>
+#include <wrn/coreip/netinet/in.h>
+#else
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <netinet/in.h>
@@ -57,6 +61,7 @@
 #include <unistd.h>
 #include <errno.h>
 #include <stdarg.h>
+#endif
 
 #include "olsr.h"
 #include "ipcalc.h"
@@ -69,6 +74,7 @@
 #include "link_set.h"
 #include "socket_parser.h"
 #include "net_olsr.h"
+#include "lq_plugin.h"
 
 #include "olsrd_dot_draw.h"
 #include "olsrd_plugin.h"
@@ -78,12 +84,15 @@
 #define close(x) closesocket(x)
 #endif
 
+#ifdef _WRS_KERNEL
+static int ipc_open;
+static int ipc_socket_up;
+#define DOT_DRAW_PORT 2004
+#endif
 
 static int ipc_socket;
 static int ipc_connection;
 
-
-
 /* IPC initialization function */
 static int
 plugin_ipc_init(void);
@@ -99,7 +108,7 @@ static void
 ipc_print_neigh_link(const struct neighbor_entry *neighbor);
 
 static void
-ipc_print_tc_link(const struct tc_entry *entry, const struct tc_edge_entry *dst_entry);
+ipc_print_tc_link(const struct tc_entry *, const struct tc_edge_entry *);
 
 static void
 ipc_print_net(const union olsr_ip_addr *, const union olsr_ip_addr *, olsr_u8_t);
@@ -119,8 +128,11 @@ ipc_send_fmt(const char *format, ...) __attribute__((format(printf,1,2)));
  *This function is called by the my_init
  *function in uolsrd_plugin.c
  */
-int
-olsrd_plugin_init(void)
+#ifdef _WRS_KERNEL
+int olsrd_dotdraw_init(void)
+#else
+int olsrd_plugin_init(void)
+#endif
 {
   /* Initial IPC value */
   ipc_socket = -1;
@@ -138,8 +150,11 @@ olsrd_plugin_init(void)
 /**
  * destructor - called at unload
  */
-void
-olsr_plugin_exit(void)
+#ifdef _WRS_KERNEL
+void olsrd_dotdraw_exit(void)
+#else
+void olsr_plugin_exit(void)
+#endif
 {
   if (ipc_connection != -1) {
     CLOSE(ipc_connection);
@@ -154,25 +169,26 @@ static void
 ipc_print_neigh_link(const struct neighbor_entry *neighbor)
 {
   struct ipaddr_str mainaddrstrbuf, strbuf;
-  double etx = 0.0;
+  olsr_linkcost etx = 0.0;
   const char *style;
   const char *adr = olsr_ip_to_string(&mainaddrstrbuf, &olsr_cnf->main_addr);
   struct link_entry* link;
-
-  if (neighbor->status == 0) { // non SYM
+  struct lqtextbuffer lqbuffer;
+  
+  if (neighbor->status == 0) { /* non SYM */
     style = "dashed";
   } else {   
     link = get_best_link_to_neighbor(&neighbor->neighbor_main_addr);
     if (link) {
-      etx = olsr_calc_link_etx(link);
+      etx = link->linkcost;
     }
     style = "solid";
   }
     
-  ipc_send_fmt("\"%s\" -> \"%s\"[label=\"%.2f\", style=%s];\n",
+  ipc_send_fmt("\"%s\" -> \"%s\"[label=\"%s\", style=%s];\n",
                adr,
                olsr_ip_to_string(&strbuf, &neighbor->neighbor_main_addr),
-               etx,
+               get_linkcost_text(etx, OLSR_FALSE, &lqbuffer),
                style);
   
   if (neighbor->is_mpr) {
@@ -235,7 +251,9 @@ plugin_ipc_init(void)
   }
 
   /* Register with olsrd */
-  //printf("Adding socket with olsrd\n");
+#if 0
+  printf("Adding socket with olsrd\n");
+#endif
   add_olsr_socket(ipc_socket, &ipc_action);
 
   return 1;
@@ -257,13 +275,16 @@ ipc_action(int fd __attribute__((unused)))
     olsr_printf(1, "(DOT DRAW)IPC accept: %s\n", strerror(errno));
     return;
   }
+#ifndef _WRS_KERNEL
   if (!ip4equal(&pin.sin_addr, &ipc_accept_ip.v4)) {
     olsr_printf(0, "Front end-connection from foreign host (%s) not allowed!\n", inet_ntoa(pin.sin_addr));
     CLOSE(ipc_connection);
     return;
   }
+#endif
   olsr_printf(1, "(DOT DRAW)IPC: Connection from %s\n", inet_ntoa(pin.sin_addr));
   pcf_event(1, 1, 1);
+  close(ipc_connection); /* close connection after one output */
 }
 
 
@@ -275,47 +296,45 @@ pcf_event(int changes_neighborhood,
 	  int changes_topology,
 	  int changes_hna)
 {
+  struct neighbor_entry *neighbor_table_tmp;
+  struct tc_entry *tc;
+  struct tc_edge_entry *tc_edge;
+  struct hna_entry *tmp_hna;
+  struct hna_net *tmp_net;
+  struct ip_prefix_list *hna;
   int res = 0;
-  if(changes_neighborhood || changes_topology || changes_hna) {
-    struct neighbor_entry *neighbor_table_tmp;
-    struct tc_entry *tc;
-    struct tc_edge_entry *tc_edge;
-    struct ip_prefix_list *hna;
-    int idx;
+
+  if (changes_neighborhood || changes_topology || changes_hna) {
     
     /* Print tables to IPC socket */
     ipc_send_str("digraph topology\n{\n");
 
     /* Neighbors */
-    for (idx = 0; idx < HASHSIZE; idx++) {	  
-      for(neighbor_table_tmp = neighbortable[idx].next;
-          neighbor_table_tmp != &neighbortable[idx];
-          neighbor_table_tmp = neighbor_table_tmp->next){
-        ipc_print_neigh_link( neighbor_table_tmp );
-      }
-    }
+    OLSR_FOR_ALL_NBR_ENTRIES(neighbor_table_tmp) {
+      ipc_print_neigh_link( neighbor_table_tmp );
+    } OLSR_FOR_ALL_NBR_ENTRIES_END(neighbor_table_tmp);
 
     /* Topology */  
     OLSR_FOR_ALL_TC_ENTRIES(tc) {
       OLSR_FOR_ALL_TC_EDGE_ENTRIES(tc, tc_edge) {
-        ipc_print_tc_link(tc, tc_edge);
+        if (tc_edge->edge_inv) {
+          ipc_print_tc_link(tc, tc_edge);
+        }
       } OLSR_FOR_ALL_TC_EDGE_ENTRIES_END(tc, tc_edge);
     } OLSR_FOR_ALL_TC_ENTRIES_END(tc);
 
     /* HNA entries */
-    for (idx = 0; idx < HASHSIZE; idx++) {
-      struct hna_entry *tmp_hna;
-      /* Check all entrys */
-      for (tmp_hna = hna_set[idx].next; tmp_hna != &hna_set[idx]; tmp_hna = tmp_hna->next) {
-        /* Check all networks */
-        struct hna_net *tmp_net;
-        for (tmp_net = tmp_hna->networks.next; tmp_net != &tmp_hna->networks; tmp_net = tmp_net->next) {
-          ipc_print_net(&tmp_hna->A_gateway_addr, 
-                        &tmp_net->A_network_addr, 
-                        tmp_net->prefixlen);
-        }
+    OLSR_FOR_ALL_HNA_ENTRIES(tmp_hna) {
+
+      /* Check all networks */
+      for (tmp_net = tmp_hna->networks.next;
+           tmp_net != &tmp_hna->networks;
+           tmp_net = tmp_net->next) {
+        ipc_print_net(&tmp_hna->A_gateway_addr, 
+                      &tmp_net->A_network_addr, 
+                      tmp_net->prefixlen);
       }
-    }
+    } OLSR_FOR_ALL_HNA_ENTRIES_END(tmp_hna);
 
     /* Local HNA entries */
     for (hna = olsr_cnf->hna_entries; hna != NULL; hna = hna->next) {
@@ -338,11 +357,12 @@ static void
 ipc_print_tc_link(const struct tc_entry *entry, const struct tc_edge_entry *dst_entry)
 {
   struct ipaddr_str strbuf1, strbuf2;
-
-  ipc_send_fmt("\"%s\" -> \"%s\"[label=\"%.2f\"];\n",
+  struct lqtextbuffer lqbuffer;
+  
+  ipc_send_fmt("\"%s\" -> \"%s\"[label=\"%s\"];\n",
                olsr_ip_to_string(&strbuf1, &entry->addr),
                olsr_ip_to_string(&strbuf2, &dst_entry->T_dest_addr),
-               olsr_calc_tc_etx(dst_entry));
+               get_linkcost_text(dst_entry->cost, OLSR_FALSE, &lqbuffer));
 }
 
 
@@ -365,7 +385,8 @@ static void
 ipc_send(const char *data, int size)
 {
   if (ipc_connection != -1) {
-#if defined __FreeBSD__ || defined __NetBSD__ || defined __OpenBSD__ || defined __MacOSX__
+#if defined __FreeBSD__ || defined __NetBSD__ || defined __OpenBSD__ || defined __MacOSX__ || \
+defined _WRS_KERNEL
 #define FLAGS 0
 #else
 #define FLAGS MSG_NOSIGNAL
@@ -390,3 +411,9 @@ ipc_send_fmt(const char *format, ...)
     ipc_send(buf, len);
   }
 }
+
+/*
+ * Local Variables:
+ * c-basic-offset: 2
+ * End:
+ */
