@@ -138,8 +138,8 @@ build_admin_body(char *buf, olsr_u32_t bufsize __attribute__((unused)))
   if(olsr_cnf->lq_level) {
     size += snprintf(&buf[size], bufsize-size, admin_basic_setting_int,
                      "LQ level:", "lq_level", 1, olsr_cnf->lq_level);
-    size += snprintf(&buf[size], bufsize-size, admin_basic_setting_int,
-                     "LQ winsize:", "lq_wsize", 2, olsr_cnf->lq_wsize);
+    size += snprintf(&buf[size], bufsize-size, admin_basic_setting_float,
+                     "LQ aging:", "lq_aging", 2, olsr_cnf->lq_aging);
   } else {
     size += snprintf(&buf[size], bufsize-size, "<td>LQ disabled</td>\n");
   }
@@ -336,9 +336,9 @@ process_param(char *key, char *value)
       while(key[7 + seperator] != '*') {
 	seperator++;
       }
-      strncpy(ip_net, &key[7], seperator);
+      memcpy(ip_net, &key[7], seperator);
       ip_net[seperator] = 0;
-      strncpy(ip_mask, &key[7 + seperator + 1], 16);
+      memcpy(ip_mask, &key[7 + seperator + 1], 16);
       olsr_printf(1, "Deleting HNA %s/%s\n", ip_net, ip_mask);
 
       if(inet_aton(ip_net, &net) == 0)
