@@ -11,9 +11,6 @@ strndup(const char *ptr, size_t size)
   size_t len = strlen(ptr);
   char *ret = NULL;
 
-  if(!len)
-    return NULL;
-
   if(len > size)
     len = size;
 
@@ -22,7 +19,7 @@ strndup(const char *ptr, size_t size)
   if(!ret)
     return NULL;
 
-  strncpy(ret, ptr, len);
+  memcpy(ret, ptr, len);
   ret[len] = '\0';
 
   return ret;
