@@ -1,13 +1,12 @@
+
 /*
- * $Id: zassert.h,v 1.1 2007/01/31 12:38:26 bernd67 Exp $
  */
 
 #ifndef _QUAGGA_ASSERT_H
 #define _QUAGGA_ASSERT_H
 
-extern void _zlog_assert_failed (const char *assertion, const char *file,
-				 unsigned int line, const char *function)
-				 __attribute__ ((noreturn));
+extern void _zlog_assert_failed(const char *assertion, const char *file, unsigned int line, const char *function)
+  __attribute__ ((noreturn));
 
 #if defined(__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
 #define __ASSERT_FUNCTION    __func__
@@ -25,3 +24,10 @@ extern void _zlog_assert_failed (const char *assertion, const char *file,
 #define assert(EX) zassert(EX)
 
 #endif /* _QUAGGA_ASSERT_H */
+
+/*
+ * Local Variables:
+ * c-basic-offset: 2
+ * indent-tabs-mode: nil
+ * End:
+ */
