@@ -1,34 +1,35 @@
+
 /*
  * The olsr.org Optimized Link-State Routing daemon (olsrd)
  *
  * Copyright (c) 2004, Thomas Lopatic (thomas@olsr.org)
  * All rights reserved.
  *
- * Redistribution and use in source and binary forms, with or without 
- * modification, are permitted provided that the following conditions 
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
  * are met:
  *
- * * Redistributions of source code must retain the above copyright 
+ * * Redistributions of source code must retain the above copyright
  *   notice, this list of conditions and the following disclaimer.
- * * Redistributions in binary form must reproduce the above copyright 
- *   notice, this list of conditions and the following disclaimer in 
- *   the documentation and/or other materials provided with the 
+ * * Redistributions in binary form must reproduce the above copyright
+ *   notice, this list of conditions and the following disclaimer in
+ *   the documentation and/or other materials provided with the
  *   distribution.
- * * Neither the name of olsr.org, olsrd nor the names of its 
- *   contributors may be used to endorse or promote products derived 
+ * * Neither the name of olsr.org, olsrd nor the names of its
+ *   contributors may be used to endorse or promote products derived
  *   from this software without specific prior written permission.
  *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
- * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
- * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
- * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
- * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
- * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
- * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
- * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
- * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+ * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
+ * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
+ * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
+ * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
+ * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
+ * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
+ * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
+ * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
+ * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
  * POSSIBILITY OF SUCH DAMAGE.
  *
  * Visit http://www.olsr.org for more information.
@@ -37,7 +38,6 @@
  * to the project. For more information see the website or contact
  * the copyright holders.
  *
- * $Id: glua_ext.c,v 1.3 2005/04/13 22:53:13 tlopatic Exp $
  */
 
 #include "lua/lua.h"
@@ -54,7 +54,8 @@
 
 #include <string.h>
 
-static char *getToken(char **point)
+static char *
+getToken(char **point)
 {
   char *localPoint = *point;
   char *start;
@@ -74,7 +75,8 @@ static char *getToken(char **point)
   return start;
 }
 
-int tasOlsrSendMessage(lua_State *lua)
+int
+tasOlsrSendMessage(lua_State * lua)
 {
   const char *service;
   const char *string;
@@ -88,7 +90,8 @@ int tasOlsrSendMessage(lua_State *lua)
   return 0;
 }
 
-int tasOlsrGetMessage(lua_State *lua)
+int
+tasOlsrGetMessage(lua_State * lua)
 {
   const char *service;
   char *string;
@@ -96,14 +99,12 @@ int tasOlsrGetMessage(lua_State *lua)
 
   service = luaL_checkstring(lua, 1);
 
-  if (httpGetTasMessage(service, &string, &from) < 0)
-  {
+  if (httpGetTasMessage(service, &string, &from) < 0) {
     lua_pushnil(lua);
     lua_pushnil(lua);
   }
 
-  else
-  {
+  else {
     lua_pushstring(lua, string);
     lua_pushstring(lua, from);
 
@@ -114,15 +115,15 @@ int tasOlsrGetMessage(lua_State *lua)
   return 2;
 }
 
-static void addSubTable(lua_State *lua, char **walker)
+static void
+addSubTable(lua_State * lua, char **walker)
 {
   char *token;
   unsigned int val;
 
   token = getToken(walker);
 
-  if (token == NULL)
-  {
+  if (token == NULL) {
     error("premature end of buffer\n");
     return;
   }
@@ -135,12 +136,10 @@ static void addSubTable(lua_State *lua, char **walker)
 
   lua_newtable(lua);
 
-  while (**walker != 0)
-  {
+  while (**walker != 0) {
     token = getToken(walker);
 
-    if (token == NULL)
-    {
+    if (token == NULL) {
       error("premature end of buffer\n");
       return;
     }
@@ -151,8 +150,7 @@ static void addSubTable(lua_State *lua, char **walker)
     if (strcmp(token, "[") == 0)
       addSubTable(lua, walker);
 
-    else
-    {
+    else {
       if (stringToInt(&val, token) < 0)
         lua_pushstring(lua, token);
 
@@ -161,8 +159,7 @@ static void addSubTable(lua_State *lua, char **walker)
 
       token = getToken(walker);
 
-      if (token == NULL)
-      {
+      if (token == NULL) {
         error("premature end of buffer\n");
         return;
       }
@@ -174,8 +171,8 @@ static void addSubTable(lua_State *lua, char **walker)
   }
 }
 
-static void addTable(lua_State *lua, char *name, void (*init)(void),
-                     int (*next)(char *buff, int len))
+static void
+addTable(lua_State * lua, const char *name, void (*init) (void), int (*next) (char *buff, int len))
 {
   int i;
   char buff[1024], *walker, *token;
@@ -187,19 +184,16 @@ static void addTable(lua_State *lua, char *name, void (*init)(void),
 
   i = 0;
 
-  while (next(buff, sizeof (buff)) >= 0)
-  {
+  while (next(buff, sizeof(buff)) >= 0) {
     walker = buff;
 
     lua_pushnumber(lua, i++);
     lua_newtable(lua);
 
-    while (*walker != 0)
-    {
+    while (*walker != 0) {
       token = getToken(&walker);
 
-      if (token == NULL)
-      {
+      if (token == NULL) {
         error("premature end of buffer\n");
         return;
       }
@@ -207,14 +201,12 @@ static void addTable(lua_State *lua, char *name, void (*init)(void),
       if (strcmp(token, "[") == 0)
         addSubTable(lua, &walker);
 
-      else
-      {
+      else {
         lua_pushstring(lua, token);
 
         token = getToken(&walker);
 
-        if (token == NULL)
-        {
+        if (token == NULL) {
           error("premature end of buffer\n");
           return;
         }
@@ -231,7 +223,8 @@ static void addTable(lua_State *lua, char *name, void (*init)(void),
   lua_settable(lua, -3);
 }
 
-int tasOlsrGetInfo(lua_State *lua)
+int
+tasOlsrGetInfo(lua_State * lua)
 {
   lua_newtable(lua);
 
@@ -242,3 +235,10 @@ int tasOlsrGetInfo(lua_State *lua)
 
   return 1;
 }
+
+/*
+ * Local Variables:
+ * c-basic-offset: 2
+ * indent-tabs-mode: nil
+ * End:
+ */
