@@ -1,34 +1,35 @@
+
 /*
  * The olsr.org Optimized Link-State Routing daemon (olsrd)
  *
  * Copyright (c) 2004, Thomas Lopatic (thomas@olsr.org)
  * All rights reserved.
  *
- * Redistribution and use in source and binary forms, with or without 
- * modification, are permitted provided that the following conditions 
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
  * are met:
  *
- * * Redistributions of source code must retain the above copyright 
+ * * Redistributions of source code must retain the above copyright
  *   notice, this list of conditions and the following disclaimer.
- * * Redistributions in binary form must reproduce the above copyright 
- *   notice, this list of conditions and the following disclaimer in 
- *   the documentation and/or other materials provided with the 
+ * * Redistributions in binary form must reproduce the above copyright
+ *   notice, this list of conditions and the following disclaimer in
+ *   the documentation and/or other materials provided with the
  *   distribution.
- * * Neither the name of olsr.org, olsrd nor the names of its 
- *   contributors may be used to endorse or promote products derived 
+ * * Neither the name of olsr.org, olsrd nor the names of its
+ *   contributors may be used to endorse or promote products derived
  *   from this software without specific prior written permission.
  *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
- * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
- * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
- * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
- * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
- * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
- * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
- * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
- * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+ * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
+ * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
+ * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
+ * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
+ * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
+ * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
+ * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
+ * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
+ * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
  * POSSIBILITY OF SUCH DAMAGE.
  *
  * Visit http://www.olsr.org for more information.
@@ -37,21 +38,18 @@
  * to the project. For more information see the website or contact
  * the copyright holders.
  *
- * $Id: http.h,v 1.3 2007/09/17 21:57:06 bernd67 Exp $
  */
 
-#include "olsrd_plugin.h" /* union set_plugin_parameter_addon */
+#include "olsrd_plugin.h"       /* union set_plugin_parameter_addon */
 
 #define CHUNK_SIZE 1024
 
-struct chunk
-{
+struct chunk {
   struct chunk *next;
   unsigned char data[CHUNK_SIZE];
 };
 
-struct inOutBuff
-{
+struct inOutBuff {
   int off, len;
   int cont;
   struct chunk *first, *last;
@@ -59,14 +57,12 @@ struct inOutBuff
 
 #define BUFF_SIZE 1024
 
-struct workBuff
-{
+struct workBuff {
   struct workBuff *next;
   unsigned char *data;
 };
 
-struct httpHeader
-{
+struct httpHeader {
   struct httpHeader *next;
   char *name;
   char *value;
@@ -79,8 +75,7 @@ struct httpHeader
 #define STATE_LSP 4
 #define STATE_DRAIN 5
 
-struct connInfo
-{
+struct connInfo {
   struct fileId *sockId;
   struct ipAddr *addr;
 
@@ -106,7 +101,7 @@ struct connInfo
   char *para;
   char *proto;
 
-  char *contType;
+  const char *contType;
   int contLen;
 
   struct sessInfo *newSess;
@@ -135,10 +130,15 @@ extern int httpSetMessLimit(const char *limitStr, void *data, set_plugin_paramet
 extern int httpSetup(void);
 extern int httpService(int freq);
 extern void httpShutdown(void);
-extern void httpAddTasMessage(const char *service, const char *string,
-                              const char *from);
+extern void httpAddTasMessage(const char *service, const char *string, const char *from);
 extern int httpGetTasMessage(const char *service, char **string, char **from);
 
-extern void writeBuff(struct inOutBuff *write, const unsigned char *data,
-                      int dataLen);
+extern void writeBuff(struct inOutBuff *write, const unsigned char *data, int dataLen);
 extern void *allocBuff(struct connInfo *info, int len);
+
+/*
+ * Local Variables:
+ * c-basic-offset: 2
+ * indent-tabs-mode: nil
+ * End:
+ */
