@@ -1,10 +1,9 @@
+
 /*
-** $Id: lfunc.c,v 1.1 2005/04/12 17:17:26 tlopatic Exp $
 ** Auxiliary functions to manipulate prototypes and closures
 ** See Copyright Notice in lua.h
 */
 
-
 #include <stdlib.h>
 
 #define lfunc_c
@@ -17,16 +16,15 @@
 #include "lobject.h"
 #include "lstate.h"
 
-
 #define sizeCclosure(n)	(cast(int, sizeof(CClosure)) + \
                          cast(int, sizeof(TObject)*((n)-1)))
 
 #define sizeLclosure(n)	(cast(int, sizeof(LClosure)) + \
                          cast(int, sizeof(TObject *)*((n)-1)))
 
-
-
-Closure *luaF_newCclosure (lua_State *L, int nelems) {
+Closure *
+luaF_newCclosure(lua_State * L, int nelems)
+{
   Closure *c = cast(Closure *, luaM_malloc(L, sizeCclosure(nelems)));
   luaC_link(L, valtogco(c), LUA_TFUNCTION);
   c->c.isC = 1;
@@ -34,8 +32,9 @@ Closure *luaF_newCclosure (lua_State *L, int nelems) {
   return c;
 }
 
-
-Closure *luaF_newLclosure (lua_State *L, int nelems, TObject *e) {
+Closure *
+luaF_newLclosure(lua_State * L, int nelems, TObject * e)
+{
   Closure *c = cast(Closure *, luaM_malloc(L, sizeLclosure(nelems)));
   luaC_link(L, valtogco(c), LUA_TFUNCTION);
   c->l.isC = 0;
@@ -44,37 +43,41 @@ Closure *luaF_newLclosure (lua_State *L, int nelems, TObject *e) {
   return c;
 }
 
-
-UpVal *luaF_findupval (lua_State *L, StkId level) {
+UpVal *
+luaF_findupval(lua_State * L, StkId level)
+{
   GCObject **pp = &L->openupval;
   UpVal *p;
   UpVal *v;
   while ((p = ngcotouv(*pp)) != NULL && p->v >= level) {
-    if (p->v == level) return p;
+    if (p->v == level)
+      return p;
     pp = &p->next;
   }
-  v = luaM_new(L, UpVal);  /* not found: create a new one */
+  v = luaM_new(L, UpVal);       /* not found: create a new one */
   v->tt = LUA_TUPVAL;
-  v->marked = 1;  /* open upvalues should not be collected */
-  v->v = level;  /* current value lives in the stack */
-  v->next = *pp;  /* chain it in the proper position */
+  v->marked = 1;                /* open upvalues should not be collected */
+  v->v = level;                 /* current value lives in the stack */
+  v->next = *pp;                /* chain it in the proper position */
   *pp = valtogco(v);
   return v;
 }
 
-
-void luaF_close (lua_State *L, StkId level) {
+void
+luaF_close(lua_State * L, StkId level)
+{
   UpVal *p;
   while ((p = ngcotouv(L->openupval)) != NULL && p->v >= level) {
-    setobj(&p->value, p->v);  /* save current value (write barrier) */
-    p->v = &p->value;  /* now current value lives here */
-    L->openupval = p->next;  /* remove from `open' list */
+    setobj(&p->value, p->v);    /* save current value (write barrier) */
+    p->v = &p->value;           /* now current value lives here */
+    L->openupval = p->next;     /* remove from `open' list */
     luaC_link(L, valtogco(p), LUA_TUPVAL);
   }
 }
 
-
-Proto *luaF_newproto (lua_State *L) {
+Proto *
+luaF_newproto(lua_State * L)
+{
   Proto *f = luaM_new(L, Proto);
   luaC_link(L, valtogco(f), LUA_TPROTO);
   f->k = NULL;
@@ -98,8 +101,9 @@ Proto *luaF_newproto (lua_State *L) {
   return f;
 }
 
-
-void luaF_freeproto (lua_State *L, Proto *f) {
+void
+luaF_freeproto(lua_State * L, Proto * f)
+{
   luaM_freearray(L, f->code, f->sizecode, Instruction);
   luaM_freearray(L, f->p, f->sizep, Proto *);
   luaM_freearray(L, f->k, f->sizek, TObject);
@@ -109,27 +113,34 @@ void luaF_freeproto (lua_State *L, Proto *f) {
   luaM_freelem(L, f);
 }
 
-
-void luaF_freeclosure (lua_State *L, Closure *c) {
-  int size = (c->c.isC) ? sizeCclosure(c->c.nupvalues) :
-                          sizeLclosure(c->l.nupvalues);
+void
+luaF_freeclosure(lua_State * L, Closure * c)
+{
+  int size = (c->c.isC) ? sizeCclosure(c->c.nupvalues) : sizeLclosure(c->l.nupvalues);
   luaM_free(L, c, size);
 }
 
-
 /*
 ** Look for n-th local variable at line `line' in function `func'.
 ** Returns NULL if not found.
 */
-const char *luaF_getlocalname (const Proto *f, int local_number, int pc) {
+const char *
+luaF_getlocalname(const Proto * f, int local_number, int pc)
+{
   int i;
-  for (i = 0; i<f->sizelocvars && f->locvars[i].startpc <= pc; i++) {
-    if (pc < f->locvars[i].endpc) {  /* is variable active? */
+  for (i = 0; i < f->sizelocvars && f->locvars[i].startpc <= pc; i++) {
+    if (pc < f->locvars[i].endpc) {     /* is variable active? */
       local_number--;
       if (local_number == 0)
         return getstr(f->locvars[i].varname);
     }
   }
-  return NULL;  /* not found */
+  return NULL;                  /* not found */
 }
 
+/*
+ * Local Variables:
+ * c-basic-offset: 2
+ * indent-tabs-mode: nil
+ * End:
+ */
