@@ -1,11 +1,6 @@
 #!/bin/sh
 
 if test -n "$OS"; then
-	# cygwin exports the OS environment vaiable - fix it. 
-	# otherwiese accept the user supplied OS
-	case "$OS" in
-		Windows*)	OS=win32 ;;
-	esac
 	echo $OS;
 	exit;
 else
@@ -17,7 +12,7 @@ else
 		freebsd*)	arch=fbsd ;;
 		netbsd*)	arch=nbsd ;;
 		openbsd*)	arch=obsd ;;
-		darwin*)		arch=osx ;;
+		darwin*)	arch=osx ;;
 		cygwin_*)	arch=win32 ;;
 		Windows_*)	arch=win32 ;;
 		*)		arch="UNKNOWN" ;;
