@@ -44,6 +44,7 @@
 
 #include "hashing.h"
 #include "olsr_types.h"
+#include "mantissa.h"
 
 #include <time.h>
 
@@ -53,11 +54,14 @@ struct hna_net
 {
   union olsr_ip_addr A_network_addr;
   olsr_u8_t          prefixlen;
-  clock_t            A_time;
+  struct timer_entry *hna_net_timer;
+  struct hna_entry   *hna_gw; /* backpointer to the owning HNA entry */
   struct hna_net     *next;
   struct hna_net     *prev;
 };
 
+#define OLSR_HNA_NET_JITTER 5 /* percent */
+
 struct hna_entry
 {
   union olsr_ip_addr A_gateway_addr;
@@ -66,6 +70,14 @@ struct hna_entry
   struct hna_entry   *prev;
 };
 
+#define OLSR_FOR_ALL_HNA_ENTRIES(hna) \
+{ \
+  int _idx; \
+  for (_idx = 0; _idx < HASHSIZE; _idx++) { \
+    for(hna = hna_set[_idx].next; \
+        hna != &hna_set[_idx]; \
+        hna = hna->next)
+#define OLSR_FOR_ALL_HNA_ENTRIES_END(hna) }}
 
 extern struct hna_entry hna_set[HASHSIZE];
 
@@ -86,12 +98,15 @@ struct hna_net *
 olsr_add_hna_net(struct hna_entry *, const union olsr_ip_addr *, olsr_u8_t);
 
 void
-olsr_update_hna_entry(const union olsr_ip_addr *, const union olsr_ip_addr *, olsr_u8_t, const float);
-
-void
-olsr_time_out_hna_set(void *);
+olsr_update_hna_entry(const union olsr_ip_addr *, const union olsr_ip_addr *, olsr_u8_t, olsr_reltime);
 
 void
 olsr_print_hna_set(void);
 
 #endif
+
+/*
+ * Local Variables:
+ * c-basic-offset: 2
+ * End:
+ */
