@@ -44,6 +44,7 @@
 #include "link_set.h"
 #include "lq_mpr.h"
 #include "scheduler.h"
+#include "lq_plugin.h"
 
 void olsr_calculate_lq_mpr(void)
 {
@@ -51,88 +52,85 @@ void olsr_calculate_lq_mpr(void)
   struct neighbor_list_entry *walker;
   int i, k;
   struct neighbor_entry *neigh;
-  double best, best_1hop;
+  olsr_linkcost best, best_1hop;
   olsr_bool mpr_changes = OLSR_FALSE;
 
-  for(i = 0; i < HASHSIZE; i++)
-    {
-      for (neigh = neighbortable[i].next;
-           neigh != &neighbortable[i];
-           neigh = neigh->next)
-        { 
-          // memorize previous MPR status
+  OLSR_FOR_ALL_NBR_ENTRIES(neigh) {
 
-          neigh->was_mpr = neigh->is_mpr;
+    /* Memorize previous MPR status. */
 
-          // clear current MPR status
+    neigh->was_mpr = neigh->is_mpr;
 
-          neigh->is_mpr = OLSR_FALSE;
+    /* Clear current MPR status. */
 
-          // in this pass we are only interested in WILL_ALWAYS neighbours
+    neigh->is_mpr = OLSR_FALSE;
 
-          if(neigh->status == NOT_SYM ||
-             neigh->willingness != WILL_ALWAYS)
-            continue;
+    /* In this pass we are only interested in WILL_ALWAYS neighbours */
 
-          neigh->is_mpr = OLSR_TRUE;
-
-          if (neigh->is_mpr != neigh->was_mpr)
-            mpr_changes = OLSR_TRUE;
-        }
+    if (neigh->status == NOT_SYM || neigh->willingness != WILL_ALWAYS) {
+      continue;
     }
 
+    neigh->is_mpr = OLSR_TRUE;
+
+    if (neigh->is_mpr != neigh->was_mpr) {
+      mpr_changes = OLSR_TRUE;
+    }
+
+  } OLSR_FOR_ALL_NBR_ENTRIES_END(neigh);
+
   for(i = 0; i < HASHSIZE; i++)
     {
-      // loop through all 2-hop neighbours
+      /* loop through all 2-hop neighbours */
 
       for (neigh2 = two_hop_neighbortable[i].next;
            neigh2 != &two_hop_neighbortable[i];
            neigh2 = neigh2->next)
         {
-          best_1hop = -1.0;
+          best_1hop = LINK_COST_BROKEN;
 
-          // check whether this 2-hop neighbour is also a neighbour
+          /* check whether this 2-hop neighbour is also a neighbour */
 
           neigh = olsr_lookup_neighbor_table(&neigh2->neighbor_2_addr);
 
-          // if it's a neighbour and also symmetric, then examine
-          // the link quality
+          /* if it's a neighbour and also symmetric, then examine
+             the link quality */
           
           if (neigh != NULL && neigh->status == SYM)
             {
-              // if the direct link is better than the best route via
-              // an MPR, then prefer the direct link and do not select
-              // an MPR for this 2-hop neighbour
+              /* if the direct link is better than the best route via
+               * an MPR, then prefer the direct link and do not select
+               * an MPR for this 2-hop neighbour */
 
-              // determine the link quality of the direct link
+              /* determine the link quality of the direct link */
 
               struct link_entry *lnk = get_best_link_to_neighbor(&neigh->neighbor_main_addr);
 
 	      if (!lnk)
 		continue;
 
-              best_1hop = lnk->loss_link_quality * lnk->neigh_link_quality;
+              best_1hop = lnk->linkcost;
 
-              // see wether we find a better route via an MPR
+              /* see wether we find a better route via an MPR */
 
               for (walker = neigh2->neighbor_2_nblist.next;
                    walker != &neigh2->neighbor_2_nblist;
                    walker = walker->next)
-                if (walker->path_link_quality > best_1hop)
+                if (walker->path_linkcost < best_1hop)
                   break;
 
-              // we've reached the end of the list, so we haven't found
-              // a better route via an MPR - so, skip MPR selection for
-              // this 1-hop neighbor
+              /* we've reached the end of the list, so we haven't found
+               * a better route via an MPR - so, skip MPR selection for
+               * this 1-hop neighbor */
 
               if (walker == &neigh2->neighbor_2_nblist)
                 continue;
             }
 
-          // find the connecting 1-hop neighbours with the
-          // best total link qualities
+          /* find the connecting 1-hop neighbours with the
+           * best total link qualities */
 
-          // mark all 1-hop neighbours as not selected
+          /* mark all 1-hop neighbours as not selected */
 
           for (walker = neigh2->neighbor_2_nblist.next;
                walker != &neigh2->neighbor_2_nblist;
@@ -141,27 +139,27 @@ void olsr_calculate_lq_mpr(void)
 
           for (k = 0; k < olsr_cnf->mpr_coverage; k++)
             {
-              // look for the best 1-hop neighbour that we haven't
-              // yet selected
+              /* look for the best 1-hop neighbour that we haven't
+               * yet selected */
 
               neigh = NULL;
-              best = -1.0;
+              best = LINK_COST_BROKEN;
 
               for (walker = neigh2->neighbor_2_nblist.next;
                    walker != &neigh2->neighbor_2_nblist;
                    walker = walker->next)
                 if (walker->neighbor->status == SYM &&
                     !walker->neighbor->skip &&
-                    walker->path_link_quality > best)
+                    walker->path_linkcost < best)
                   {
                     neigh = walker->neighbor;
-                    best = walker->path_link_quality;
+                    best = walker->path_linkcost;
                   }
 
-              // Found a 1-hop neighbor that we haven't previously selected.
-              // Use it as MPR only when the 2-hop path through it is better than
-              // any existing 1-hop path.
-              if ((neigh != NULL) && (best > best_1hop))
+              /* Found a 1-hop neighbor that we haven't previously selected.
+               * Use it as MPR only when the 2-hop path through it is better than
+               * any existing 1-hop path. */
+              if ((neigh != NULL) && (best < best_1hop))
                 {
                   neigh->is_mpr = OLSR_TRUE;
                   neigh->skip = OLSR_TRUE;
@@ -170,8 +168,8 @@ void olsr_calculate_lq_mpr(void)
                     mpr_changes = OLSR_TRUE;
                 }
 
-              // no neighbour found => the requested MPR coverage cannot
-              // be satisfied => stop
+              /* no neighbour found => the requested MPR coverage cannot
+               * be satisfied => stop */
 
               else
                 break;
@@ -182,3 +180,9 @@ void olsr_calculate_lq_mpr(void)
   if (mpr_changes && olsr_cnf->tc_redundancy > 0)
     signal_link_changes(OLSR_TRUE);
 }
+
+/*
+ * Local Variables:
+ * c-basic-offset: 2
+ * End:
+ */
