@@ -1,33 +1,34 @@
+
 /*
  * The olsr.org Optimized Link-State Routing daemon(olsrd)
- * Copyright (c) 2004, Andreas Tønnesen(andreto@olsr.org)
+ * Copyright (c) 2004, Andreas Tonnesen(andreto@olsr.org)
  * All rights reserved.
  *
- * Redistribution and use in source and binary forms, with or without 
- * modification, are permitted provided that the following conditions 
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
  * are met:
  *
- * * Redistributions of source code must retain the above copyright 
+ * * Redistributions of source code must retain the above copyright
  *   notice, this list of conditions and the following disclaimer.
- * * Redistributions in binary form must reproduce the above copyright 
- *   notice, this list of conditions and the following disclaimer in 
- *   the documentation and/or other materials provided with the 
+ * * Redistributions in binary form must reproduce the above copyright
+ *   notice, this list of conditions and the following disclaimer in
+ *   the documentation and/or other materials provided with the
  *   distribution.
- * * Neither the name of olsr.org, olsrd nor the names of its 
- *   contributors may be used to endorse or promote products derived 
+ * * Neither the name of olsr.org, olsrd nor the names of its
+ *   contributors may be used to endorse or promote products derived
  *   from this software without specific prior written permission.
  *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
- * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
- * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
- * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
- * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
- * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
- * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
- * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
- * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+ * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
+ * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
+ * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
+ * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
+ * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
+ * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
+ * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
+ * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
+ * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
  * POSSIBILITY OF SUCH DAMAGE.
  *
  * Visit http://www.olsr.org for more information.
@@ -38,7 +39,6 @@
  *
  */
 
-
 #include "ipcalc.h"
 #include "defs.h"
 #include "mpr_selector_set.h"
@@ -46,7 +46,7 @@
 #include "scheduler.h"
 #include "net_olsr.h"
 
-static olsr_u16_t ansn;
+static uint16_t ansn;
 
 /* MPR selector list */
 static struct mpr_selector mprs_list;
@@ -59,17 +59,15 @@ void
 olsr_init_mprs_set(void)
 {
   OLSR_PRINTF(5, "MPRS: Init\n");
+
   /* Initial values */
   ansn = 0;
 
-  olsr_register_timeout_function(&olsr_time_out_mprs_set, OLSR_TRUE);
-  
   mprs_list.next = &mprs_list;
   mprs_list.prev = &mprs_list;
 }
 
-
-olsr_u16_t 
+uint16_t
 get_local_ansn(void)
 {
   return ansn;
@@ -82,17 +80,56 @@ increase_local_ansn(void)
 }
 
 #if 0
+
 /**
  * Check if we(this node) is selected as a MPR by any
  * neighbors. If the list is empty we are not MPR.
  */
-olsr_bool
+bool
 olsr_is_mpr(void)
 {
-    return ((mprs_list.next == &mprs_list) ? OLSR_FALSE : OLSR_TRUE);
+  return ((mprs_list.next == &mprs_list) ? false : true);
 }
 #endif
 
+/**
+ * Wrapper for the timer callback.
+ */
+static void
+olsr_expire_mpr_sel_entry(void *context)
+{
+#ifdef DEBUG
+  struct ipaddr_str buf;
+#endif
+  struct mpr_selector *mpr_sel;
+
+  mpr_sel = (struct mpr_selector *)context;
+  mpr_sel->MS_timer = NULL;
+
+#ifdef DEBUG
+  OLSR_PRINTF(1, "MPRS: Timing out %st\n", olsr_ip_to_string(&buf, &mpr_sel->MS_main_addr));
+#endif
+
+  DEQUEUE_ELEM(mpr_sel);
+
+  /* Delete entry */
+  free(mpr_sel);
+  signal_link_changes(true);
+}
+
+/**
+ * Set the mpr selector expiration timer.
+ *
+ * all timer setting shall be done using this function.
+ * The timer param is a relative timer expressed in milliseconds.
+ */
+static void
+olsr_set_mpr_sel_timer(struct mpr_selector *mpr_sel, olsr_reltime rel_timer)
+{
+
+  olsr_set_timer(&mpr_sel->MS_timer, rel_timer, OLSR_MPR_SEL_JITTER, OLSR_TIMER_ONESHOT, &olsr_expire_mpr_sel_entry, mpr_sel, 0);
+}
+
 /**
  *Add a MPR selector to the MPR selector set
  *
@@ -102,34 +139,28 @@ olsr_is_mpr(void)
  *@return a pointer to the new entry
  */
 struct mpr_selector *
-olsr_add_mpr_selector(const union olsr_ip_addr *addr, float vtime)
+olsr_add_mpr_selector(const union olsr_ip_addr *addr, olsr_reltime vtime)
 {
-#ifndef NODEBUG
   struct ipaddr_str buf;
-#endif
   struct mpr_selector *new_entry;
 
   OLSR_PRINTF(1, "MPRS: adding %s\n", olsr_ip_to_string(&buf, addr));
 
   new_entry = olsr_malloc(sizeof(struct mpr_selector), "Add MPR selector");
-
   /* Fill struct */
   new_entry->MS_main_addr = *addr;
-  new_entry->MS_time = GET_TIMESTAMP(vtime*1000);
-
+  olsr_set_mpr_sel_timer(new_entry, vtime);
   /* Queue */
   QUEUE_ELEM(mprs_list, new_entry);
   /*
-  new_entry->prev = &mprs_list;
-  new_entry->next = mprs_list.next;
-  mprs_list.next->prev = new_entry;
-  mprs_list.next = new_entry;
-  */
+     new_entry->prev = &mprs_list;
+     new_entry->next = mprs_list.next;
+     mprs_list.next->prev = new_entry;
+     mprs_list.next = new_entry;
+   */
   return new_entry;
 }
 
-
-
 /**
  *Lookup an entry in the MPR selector table
  *based on address
@@ -143,12 +174,12 @@ olsr_lookup_mprs_set(const union olsr_ip_addr *addr)
 {
   struct mpr_selector *mprs;
 
-  if(addr == NULL)
+  if (addr == NULL)
     return NULL;
   //OLSR_PRINTF(1, "MPRS: Lookup....");
 
   for (mprs = mprs_list.next; mprs != &mprs_list; mprs = mprs->next) {
-    if(ipequal(&mprs->MS_main_addr, addr)) {
+    if (ipequal(&mprs->MS_main_addr, addr)) {
       //OLSR_PRINTF(1, "MATCH\n");
       return mprs;
     }
@@ -157,7 +188,6 @@ olsr_lookup_mprs_set(const union olsr_ip_addr *addr)
   return NULL;
 }
 
-
 /**
  *Update a MPR selector entry or create an new
  *one if it does not exist
@@ -168,58 +198,24 @@ olsr_lookup_mprs_set(const union olsr_ip_addr *addr)
  *@return 1 if a new entry was added 0 if not
  */
 int
-olsr_update_mprs_set(const union olsr_ip_addr *addr, float vtime)
+olsr_update_mprs_set(const union olsr_ip_addr *addr, olsr_reltime vtime)
 {
-#ifndef NODEBUG
   struct ipaddr_str buf;
-#endif
   struct mpr_selector *mprs = olsr_lookup_mprs_set(addr);
 
   OLSR_PRINTF(5, "MPRS: Update %s\n", olsr_ip_to_string(&buf, addr));
 
-  if(mprs == NULL) {
+  if (mprs == NULL) {
     olsr_add_mpr_selector(addr, vtime);
-    signal_link_changes(OLSR_TRUE);
+    signal_link_changes(true);
     return 1;
   }
-  mprs->MS_time = GET_TIMESTAMP(vtime*1000);
+  olsr_set_mpr_sel_timer(mprs, vtime);
   return 0;
 }
 
-/**
- *Time out MPR selector entries
- *
- *@return nada
- */
-void
-olsr_time_out_mprs_set(void)
-{
-  struct mpr_selector *mprs = mprs_list.next;
-
-  while(mprs != &mprs_list) {
-      if(TIMED_OUT(mprs->MS_time))
-	{
-	  /* Dequeue */
-	  struct mpr_selector *mprs_to_delete = mprs;
-#ifndef NODEBUG
-          struct ipaddr_str buf;
-#endif
-	  mprs = mprs->next;
-
-	  OLSR_PRINTF(1, "MPRS: Timing out %s\n", olsr_ip_to_string(&buf, &mprs_to_delete->MS_main_addr));
-
-	  DEQUEUE_ELEM(mprs_to_delete);
-
-	  /* Delete entry */
-	  free(mprs_to_delete);
-	  signal_link_changes(OLSR_TRUE);
-	}
-      else
-	mprs = mprs->next;
-    }
-}
-
 #if 0
+
 /**
  *Print the current MPR selector set to STDOUT
  */
@@ -228,13 +224,17 @@ olsr_print_mprs_set(void)
 {
   struct mpr_selector *mprs;
   OLSR_PRINTF(1, "MPR SELECTORS: ");
-  for(mprs = mprs_list.next; mprs != &mprs_list; mprs = mprs->next) {
-#ifndef NODEBUG
+  for (mprs = mprs_list.next; mprs != &mprs_list; mprs = mprs->next) {
     struct ipaddr_str buf;
-#endif
     OLSR_PRINTF(1, "%s ", olsr_ip_to_string(&buf, &mprs->MS_main_addr));
   }
   OLSR_PRINTF(1, "\n");
 }
 #endif
 
+/*
+ * Local Variables:
+ * c-basic-offset: 2
+ * indent-tabs-mode: nil
+ * End:
+ */
