@@ -1,33 +1,34 @@
+
 /*
  * The olsr.org Optimized Link-State Routing daemon(olsrd)
- * Copyright (c) 2004, Andreas Tønnesen(andreto@olsr.org)
+ * Copyright (c) 2004, Andreas Tonnesen(andreto@olsr.org)
  * All rights reserved.
  *
- * Redistribution and use in source and binary forms, with or without 
- * modification, are permitted provided that the following conditions 
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
  * are met:
  *
- * * Redistributions of source code must retain the above copyright 
+ * * Redistributions of source code must retain the above copyright
  *   notice, this list of conditions and the following disclaimer.
- * * Redistributions in binary form must reproduce the above copyright 
- *   notice, this list of conditions and the following disclaimer in 
- *   the documentation and/or other materials provided with the 
+ * * Redistributions in binary form must reproduce the above copyright
+ *   notice, this list of conditions and the following disclaimer in
+ *   the documentation and/or other materials provided with the
  *   distribution.
- * * Neither the name of olsr.org, olsrd nor the names of its 
- *   contributors may be used to endorse or promote products derived 
+ * * Neither the name of olsr.org, olsrd nor the names of its
+ *   contributors may be used to endorse or promote products derived
  *   from this software without specific prior written permission.
  *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
- * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
- * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
- * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
- * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
- * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
- * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
- * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
- * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+ * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
+ * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
+ * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
+ * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
+ * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
+ * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
+ * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
+ * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
+ * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
  * POSSIBILITY OF SUCH DAMAGE.
  *
  * Visit http://www.olsr.org for more information.
@@ -51,27 +52,21 @@
 #include <assert.h>
 #include <limits.h>
 
-static olsr_bool disp_pack_out = OLSR_FALSE;
-
+static bool disp_pack_out = false;
 
 #ifdef WIN32
 #define perror(x) WinSockPError(x)
-void
-WinSockPError(const char *);
+void WinSockPError(const char *);
 #endif
 
-
-struct deny_address_entry
-{
-  union olsr_ip_addr        addr;
+struct deny_address_entry {
+  union olsr_ip_addr addr;
   struct deny_address_entry *next;
 };
 
-
 /* Packet transform functions */
 
-struct ptf
-{
+struct ptf {
   packet_transform_function function;
   struct ptf *next;
 };
@@ -80,34 +75,38 @@ static struct ptf *ptf_list;
 
 static struct deny_address_entry *deny_entries;
 
-static const char * const deny_ipv4_defaults[] =
-  {
-    "0.0.0.0",
-    "127.0.0.1",
-    NULL
-  };
+static const char *const deny_ipv4_defaults[] = {
+  "0.0.0.0",
+  "127.0.0.1",
+  NULL
+};
 
-static const char * const deny_ipv6_defaults[] =
-  {
-    "0::0",
-    "0::1",
-    NULL
-  };
+static const char *const deny_ipv6_defaults[] = {
+  "0::0",
+  "0::1",
+  NULL
+};
 
 void
-net_set_disp_pack_out(olsr_bool val)
+net_set_disp_pack_out(bool val)
 {
   disp_pack_out = val;
 }
 
+/*
+ * Converts each invalid IP-address from string to network byte order
+ * and adds it to the invalid list.
+ *
+ * TODO: rename function
+ */
 void
 init_net(void)
 {
-  const char * const *defaults = olsr_cnf->ip_version == AF_INET ? deny_ipv4_defaults : deny_ipv6_defaults;
-  
+  const char *const *defaults = (olsr_cnf->ip_version == AF_INET) ? deny_ipv4_defaults : deny_ipv6_defaults;
+
   for (; *defaults != NULL; defaults++) {
     union olsr_ip_addr addr;
-    if(inet_pton(olsr_cnf->ip_version, *defaults, &addr) <= 0){
+    if (inet_pton(olsr_cnf->ip_version, *defaults, &addr) <= 0) {
       fprintf(stderr, "Error converting fixed IP %s for deny rule!!\n", *defaults);
       continue;
     }
@@ -116,15 +115,15 @@ init_net(void)
 }
 
 /**
- * Create a outputbuffer for the given interface. This
- * function will allocate the needed storage according 
+ * Create an outputbuffer for the given interface. This
+ * function will allocate the needed storage according
  * to the MTU of the interface.
  *
  * @param ifp the interface to create a buffer for
  *
  * @return 0 on success, negative if a buffer already existed
  *  for the given interface
- */ 
+ */
 int
 net_add_buffer(struct interface *ifp)
 {
@@ -135,7 +134,7 @@ net_add_buffer(struct interface *ifp)
     free(ifp->netbuf.buff);
     ifp->netbuf.buff = NULL;
   }
-  
+
   if (ifp->netbuf.buff == NULL) {
     ifp->netbuf.buff = olsr_malloc(ifp->int_mtu, "add_netbuff");
   }
@@ -162,7 +161,7 @@ int
 net_remove_buffer(struct interface *ifp)
 {
   /* Flush pending data */
-  if(ifp->netbuf.pending)
+  if (ifp->netbuf.pending)
     net_output(ifp);
 
   free(ifp->netbuf.buff);
@@ -171,7 +170,6 @@ net_remove_buffer(struct interface *ifp)
   return 0;
 }
 
-
 /**
  * Reserve space in a outputbuffer. This should only be needed
  * in very special cases. This will decrease the reported size
@@ -189,12 +187,12 @@ net_remove_buffer(struct interface *ifp)
 int
 net_reserve_bufspace(struct interface *ifp, int size)
 {
-  if(size > ifp->netbuf.maxsize)
+  if (size > ifp->netbuf.maxsize)
     return -1;
-  
+
   ifp->netbuf.reserved = size;
   ifp->netbuf.maxsize -= size;
-  
+
   return 0;
 }
 
@@ -206,14 +204,12 @@ net_reserve_bufspace(struct interface *ifp, int size)
  *
  * @return the number of bytes currently pending
  */
-olsr_u16_t
-net_output_pending(const struct interface *ifp)
+uint16_t
+net_output_pending(const struct interface * ifp)
 {
   return ifp->netbuf.pending;
 }
 
-
-
 /**
  * Add data to a buffer.
  *
@@ -221,14 +217,14 @@ net_output_pending(const struct interface *ifp)
  * @param data a pointer to the data to add
  * @param size the number of byte to copy from data
  *
- * @return -1 if no buffer was found, 0 if there was not 
- *  enough room in buffer or the number of bytes added on 
+ * @return -1 if no buffer was found, 0 if there was not
+ *  enough room in buffer or the number of bytes added on
  *  success
  */
 int
-net_outbuffer_push(struct interface *ifp, const void *data, const olsr_u16_t size)
+net_outbuffer_push(struct interface *ifp, const void *data, const uint16_t size)
 {
-  if((ifp->netbuf.pending + size) > ifp->netbuf.maxsize)
+  if ((ifp->netbuf.pending + size) > ifp->netbuf.maxsize)
     return 0;
 
   memcpy(&ifp->netbuf.buff[ifp->netbuf.pending + OLSR_HEADERSIZE], data, size);
@@ -237,7 +233,6 @@ net_outbuffer_push(struct interface *ifp, const void *data, const olsr_u16_t siz
   return size;
 }
 
-
 /**
  * Add data to the reserved part of a buffer
  *
@@ -245,14 +240,14 @@ net_outbuffer_push(struct interface *ifp, const void *data, const olsr_u16_t siz
  * @param data a pointer to the data to add
  * @param size the number of byte to copy from data
  *
- * @return -1 if no buffer was found, 0 if there was not 
- *  enough room in buffer or the number of bytes added on 
+ * @return -1 if no buffer was found, 0 if there was not
+ *  enough room in buffer or the number of bytes added on
  *  success
  */
 int
-net_outbuffer_push_reserved(struct interface *ifp, const void *data, const olsr_u16_t size)
+net_outbuffer_push_reserved(struct interface *ifp, const void *data, const uint16_t size)
 {
-  if((ifp->netbuf.pending + size) > (ifp->netbuf.maxsize + ifp->netbuf.reserved))
+  if ((ifp->netbuf.pending + size) > (ifp->netbuf.maxsize + ifp->netbuf.reserved))
     return 0;
 
   memcpy(&ifp->netbuf.buff[ifp->netbuf.pending + OLSR_HEADERSIZE], data, size);
@@ -275,7 +270,6 @@ net_outbuffer_bytes_left(const struct interface *ifp)
   return ifp->netbuf.maxsize - ifp->netbuf.pending;
 }
 
-
 /**
  * Add a packet transform function. Theese are functions
  * called just prior to sending data in a buffer.
@@ -313,21 +307,19 @@ del_ptf(packet_transform_function f)
 {
   struct ptf *prev = NULL;
   struct ptf *tmp_ptf = ptf_list;
-  while(tmp_ptf)
-    {
-      if(tmp_ptf->function == f)
-	{
-	  /* Remove entry */
-	  if(prev == NULL)
-	      ptf_list = tmp_ptf->next;
-	  else
-	      prev->next = tmp_ptf->next;
-          free(tmp_ptf);
-	  return 1;
-	}
-      prev = tmp_ptf;
-      tmp_ptf = tmp_ptf->next;
+  while (tmp_ptf) {
+    if (tmp_ptf->function == f) {
+      /* Remove entry */
+      if (prev == NULL)
+        ptf_list = tmp_ptf->next;
+      else
+        prev->next = tmp_ptf->next;
+      free(tmp_ptf);
+      return 1;
     }
+    prev = tmp_ptf;
+    tmp_ptf = tmp_ptf->next;
+  }
 
   return 0;
 }
@@ -348,7 +340,7 @@ net_output(struct interface *ifp)
   union olsr_packet *outmsg;
   int retval;
 
-  if(!ifp->netbuf.pending)
+  if (!ifp->netbuf.pending)
     return 0;
 
   ifp->netbuf.pending += OLSR_HEADERSIZE;
@@ -361,99 +353,81 @@ net_output(struct interface *ifp)
   /* Set the packetlength */
   outmsg->v4.olsr_packlen = htons(ifp->netbuf.pending);
 
-  if(olsr_cnf->ip_version == AF_INET)
-    {
-      struct sockaddr_in dst;
-      /* IP version 4 */
-      sin = (struct sockaddr_in *)&ifp->int_broadaddr;
+  if (olsr_cnf->ip_version == AF_INET) {
+    struct sockaddr_in dst;
+    /* IP version 4 */
+    sin = (struct sockaddr_in *)&ifp->int_broadaddr;
 
-      /* Copy sin */
-      dst = *sin;
-      sin = &dst;
+    /* Copy sin */
+    dst = *sin;
+    sin = &dst;
 
-      if (sin->sin_port == 0)
-	sin->sin_port = htons(OLSRPORT);
-    }
-  else
-    {
-      struct sockaddr_in6 dst6;
-      /* IP version 6 */
-      sin6 = (struct sockaddr_in6 *)&ifp->int6_multaddr;
-      /* Copy sin */
-      dst6 = *sin6;
-      sin6 = &dst6;
-    }
+    if (sin->sin_port == 0)
+      sin->sin_port = htons(olsr_cnf->olsrport);
+  } else {
+    struct sockaddr_in6 dst6;
+    /* IP version 6 */
+    sin6 = (struct sockaddr_in6 *)&ifp->int6_multaddr;
+    /* Copy sin */
+    dst6 = *sin6;
+    sin6 = &dst6;
+  }
 
   /*
-   *Call possible packet transform functions registered by plugins  
+   *Call possible packet transform functions registered by plugins
    */
-  for (tmp_ptf_list = ptf_list; tmp_ptf_list != NULL; tmp_ptf_list = tmp_ptf_list->next)
-    {
-      tmp_ptf_list->function(ifp->netbuf.buff, &ifp->netbuf.pending);
-    }
+  for (tmp_ptf_list = ptf_list; tmp_ptf_list != NULL; tmp_ptf_list = tmp_ptf_list->next) {
+    tmp_ptf_list->function(ifp->netbuf.buff, &ifp->netbuf.pending);
+  }
 
   /*
    *if the -dispout option was given
    *we print the content of the packets
    */
-  if(disp_pack_out)
-    print_olsr_serialized_packet(stdout, (union olsr_packet *)ifp->netbuf.buff, 
-				 ifp->netbuf.pending, &ifp->ip_addr); 
-  
-  if(olsr_cnf->ip_version == AF_INET)
-    {
-      /* IP version 4 */
-      if(olsr_sendto(ifp->olsr_socket, 
-                     ifp->netbuf.buff, 
-		     ifp->netbuf.pending, 
-		     MSG_DONTROUTE, 
-		     (struct sockaddr *)sin, 
-		     sizeof (*sin))
-	 < 0)
-	{
-	  perror("sendto(v4)");
-	  olsr_syslog(OLSR_LOG_ERR, "OLSR: sendto IPv4 %m");
-	  retval = -1;
-	}
+  if (disp_pack_out)
+    print_olsr_serialized_packet(stdout, (union olsr_packet *)ifp->netbuf.buff, ifp->netbuf.pending, &ifp->ip_addr);
+
+  if (olsr_cnf->ip_version == AF_INET) {
+    /* IP version 4 */
+    if (olsr_sendto(ifp->olsr_socket, ifp->netbuf.buff, ifp->netbuf.pending, MSG_DONTROUTE, (struct sockaddr *)sin, sizeof(*sin)) <
+        0) {
+      perror("sendto(v4)");
+      olsr_syslog(OLSR_LOG_ERR, "OLSR: sendto IPv4 %m");
+      retval = -1;
     }
-  else
-    {
-      /* IP version 6 */
-      if(olsr_sendto(ifp->olsr_socket, 
-		     ifp->netbuf.buff,
-		     ifp->netbuf.pending, 
-		     MSG_DONTROUTE, 
-		     (struct sockaddr *)sin6, 
-		     sizeof (*sin6))
-	 < 0)
-	{
-          struct ipaddr_str buf;
-	  perror("sendto(v6)");
-	  olsr_syslog(OLSR_LOG_ERR, "OLSR: sendto IPv6 %m");
-	  fprintf(stderr, "Socket: %d interface: %d\n", ifp->olsr_socket, ifp->if_index);
-	  fprintf(stderr, "To: %s (size: %u)\n", ip6_to_string(&buf, &sin6->sin6_addr), (unsigned int)sizeof(*sin6));
-	  fprintf(stderr, "Outputsize: %d\n", ifp->netbuf.pending);
-	  retval = -1;
-	}
+  } else {
+    /* IP version 6 */
+    if (olsr_sendto(ifp->olsr_socket, ifp->netbuf.buff, ifp->netbuf.pending, MSG_DONTROUTE, (struct sockaddr *)sin6, sizeof(*sin6))
+        < 0) {
+      struct ipaddr_str buf;
+      perror("sendto(v6)");
+      olsr_syslog(OLSR_LOG_ERR, "OLSR: sendto IPv6 %m");
+      fprintf(stderr, "Socket: %d interface: %d\n", ifp->olsr_socket, ifp->if_index);
+      fprintf(stderr, "To: %s (size: %u)\n", ip6_to_string(&buf, &sin6->sin6_addr), (unsigned int)sizeof(*sin6));
+      fprintf(stderr, "Outputsize: %d\n", ifp->netbuf.pending);
+      retval = -1;
     }
-  
+  }
+
   ifp->netbuf.pending = 0;
 
-  // if we've just transmitted a TC message, let Dijkstra use the current
-  // link qualities for the links to our neighbours
+  /*
+   * if we've just transmitted a TC message, let Dijkstra use the current
+   * link qualities for the links to our neighbours
+   */
 
-  olsr_update_dijkstra_link_qualities();
-  lq_tc_pending = OLSR_FALSE;
+  lq_tc_pending = false;
 
   return retval;
 }
 
+/*
+ * Adds the given IP-address to the invalid list.
+ */
 void
 olsr_add_invalid_address(const union olsr_ip_addr *adr)
 {
-#ifndef NODEBUG
   struct ipaddr_str buf;
-#endif
   struct deny_address_entry *new_entry = olsr_malloc(sizeof(struct deny_address_entry), "Add deny address");
 
   new_entry->addr = *adr;
@@ -462,27 +436,26 @@ olsr_add_invalid_address(const union olsr_ip_addr *adr)
   OLSR_PRINTF(1, "Added %s to IP deny set\n", olsr_ip_to_string(&buf, &new_entry->addr));
 }
 
-
-olsr_bool
+bool
 olsr_validate_address(const union olsr_ip_addr *adr)
 {
   const struct deny_address_entry *deny_entry;
 
   for (deny_entry = deny_entries; deny_entry != NULL; deny_entry = deny_entry->next) {
-    if(ipequal(adr, &deny_entry->addr))	{
-#ifndef NODEBUG
+    if (ipequal(adr, &deny_entry->addr)) {
       struct ipaddr_str buf;
-#endif
       OLSR_PRINTF(1, "Validation of address %s failed!\n", olsr_ip_to_string(&buf, adr));
-      return OLSR_FALSE;
+      return false;
     }
-    if (deny_entry == (struct deny_address_entry *)&olsr_cnf->main_addr) break;
+    if (deny_entry == (struct deny_address_entry *)&olsr_cnf->main_addr)
+      break;
   }
-  return OLSR_TRUE;
+  return true;
 }
 
 /*
  * Local Variables:
  * c-basic-offset: 2
+ * indent-tabs-mode: nil
  * End:
  */
