@@ -48,12 +48,16 @@
 #include "neighbor_table.h"
 #include "olsr.h"
 #include "link_set.h"
-#include "lq_avl.h"
-#include "lq_route.h"
+#include "common/avl.h"
+#include "olsr_spf.h"
 #include "net_olsr.h"
 
 #include <assert.h>
 
+/* Cookies */
+struct olsr_cookie_info *rt_mem_cookie = NULL;
+struct olsr_cookie_info *rtp_mem_cookie = NULL;
+
 /*
  * Sven-Ola: if the current internet gateway is switched, the
  * NAT connection info is lost for any active TCP/UDP session.
@@ -162,9 +166,20 @@ avl_comp_ipv6_prefix (const void *prefix1, const void *prefix2)
 void
 olsr_init_routing_table(void)
 {
+  OLSR_PRINTF(5, "RIB: init routing tree\n");
+
   /* the routing tree */
   avl_init(&routingtree, avl_comp_prefix_default);
   routingtree_version = 0;
+
+  /*
+   * Get some cookies for memory stats and memory recycling.
+   */
+  rt_mem_cookie = olsr_alloc_cookie("rt_entry", OLSR_COOKIE_TYPE_MEMORY);
+  olsr_cookie_set_memory_size(rt_mem_cookie, sizeof(struct rt_entry));
+
+  rtp_mem_cookie = olsr_alloc_cookie("rt_path", OLSR_COOKIE_TYPE_MEMORY);
+  olsr_cookie_set_memory_size(rtp_mem_cookie, sizeof(struct rt_path));
 }
 
 /**
@@ -186,7 +201,7 @@ olsr_lookup_routing_table(const union olsr_ip_addr *dst)
 
   rt_tree_node = avl_find(&routingtree, &prefix);
 
-  return rt_tree_node ? rt_tree_node->data : NULL;
+  return rt_tree_node ? rt_tree2rt(rt_tree_node) : NULL;
 }
 
 /**
@@ -207,7 +222,7 @@ olsr_update_rt_path(struct rt_path *rtp, struct tc_entry *tc,
 
   /* metric/etx */
   rtp->rtp_metric.hops = tc->hops;
-  rtp->rtp_metric.etx = tc->path_etx;
+  rtp->rtp_metric.cost = tc->path_cost;
 }
 
 /**
@@ -216,7 +231,7 @@ olsr_update_rt_path(struct rt_path *rtp, struct tc_entry *tc,
 static struct rt_entry *
 olsr_alloc_rt_entry(struct olsr_ip_prefix *prefix)
 {
-  struct rt_entry *rt = olsr_malloc(sizeof(struct rt_entry), __FUNCTION__);
+  struct rt_entry *rt = olsr_cookie_malloc(rt_mem_cookie);
   if (!rt) {
     return NULL;
   }
@@ -230,7 +245,6 @@ olsr_alloc_rt_entry(struct olsr_ip_prefix *prefix)
   rt->rt_dst = *prefix;
 
   rt->rt_tree_node.key = &rt->rt_dst;
-  rt->rt_tree_node.data = rt;
   avl_insert(&routingtree, &rt->rt_tree_node, AVL_DUP_NO);
 
   /* init the originator subtree */
@@ -246,7 +260,7 @@ static struct rt_path *
 olsr_alloc_rt_path(struct tc_entry *tc,
                    struct olsr_ip_prefix *prefix, olsr_u8_t origin)
 {
-  struct rt_path *rtp = olsr_malloc(sizeof(struct rt_path), __FUNCTION__);
+  struct rt_path *rtp = olsr_cookie_malloc(rtp_mem_cookie);
 
   if (!rtp) {
     return NULL;
@@ -258,10 +272,10 @@ olsr_alloc_rt_path(struct tc_entry *tc,
 
   /* set key and backpointer prior to tree insertion */
   rtp->rtp_prefix_tree_node.key = &rtp->rtp_dst;
-  rtp->rtp_prefix_tree_node.data = rtp;
 
   /* insert to the tc prefix tree */
   avl_insert(&tc->prefix_tree, &rtp->rtp_prefix_tree_node, AVL_DUP_NO);
+  olsr_lock_tc_entry(tc);
 
   /* backlink to the owning tc entry */
   rtp->rtp_tc = tc;
@@ -286,7 +300,7 @@ olsr_insert_rt_path(struct rt_path *rtp, struct tc_entry *tc,
   /*
    * no unreachable routes please.
    */
-  if (tc->path_etx >= INFINITE_ETX) {
+  if (tc->path_cost == ROUTE_COST_BROKEN) {
     return;
   }
 
@@ -312,7 +326,7 @@ olsr_insert_rt_path(struct rt_path *rtp, struct tc_entry *tc,
     }
 
   } else {
-    rt = node->data;
+    rt = rt_tree2rt(node);
   }
 
 
@@ -321,7 +335,6 @@ olsr_insert_rt_path(struct rt_path *rtp, struct tc_entry *tc,
 
   /* set key and backpointer prior to tree insertion */
   rtp->rtp_tree_node.key = &rtp->rtp_originator;
-  rtp->rtp_tree_node.data = rtp;
 
   /* insert to the route entry originator tree */
   avl_insert(&rt->rt_path_tree, &rtp->rtp_tree_node, AVL_DUP_NO);
@@ -336,8 +349,8 @@ olsr_insert_rt_path(struct rt_path *rtp, struct tc_entry *tc,
 /**
  * Unlink and free a rt_path.
  */
-static void
-olsr_free_rt_path(struct rt_path *rtp)
+void
+olsr_delete_rt_path(struct rt_path *rtp)
 {
 
   /* remove from the originator tree */
@@ -349,6 +362,7 @@ olsr_free_rt_path(struct rt_path *rtp)
   /* remove from the tc prefix tree */
   if (rtp->rtp_tc) {
     avl_delete(&rtp->rtp_tc->prefix_tree, &rtp->rtp_prefix_tree_node);
+    olsr_unlock_tc_entry(rtp->rtp_tc);
     rtp->rtp_tc = NULL;
   }
 
@@ -357,7 +371,7 @@ olsr_free_rt_path(struct rt_path *rtp)
     current_inetgw = NULL;
   }
 
-  free(rtp);
+  olsr_cookie_free(rtp_mem_cookie, rtp);
 }
 
 
@@ -426,8 +440,8 @@ olsr_get_nh(const struct rt_entry *rt)
 static olsr_bool
 olsr_cmp_rtp(const struct rt_path *rtp1, const struct rt_path *rtp2, const struct rt_path *inetgw)
 {
-    float etx1 = rtp1->rtp_metric.etx;
-    float etx2 = rtp2->rtp_metric.etx;
+    olsr_linkcost etx1 = rtp1->rtp_metric.cost;
+    olsr_linkcost etx2 = rtp2->rtp_metric.cost;
     if (inetgw == rtp1) etx1 *= olsr_cnf->lq_nat_thresh;
     if (inetgw == rtp2) etx2 *= olsr_cnf->lq_nat_thresh;
 
@@ -476,11 +490,11 @@ olsr_rt_best(struct rt_entry *rt)
 
   assert(node != 0); /* should not happen */
 
-  rt->rt_best = node->data;
+  rt->rt_best = rtp_tree2rtp(node);
 
   /* walk all remaining originator entries */
   while ((node = avl_walk_next(node))) {
-    struct rt_path *rtp = node->data;
+    struct rt_path *rtp = rtp_tree2rtp(node);
 
     if (olsr_cmp_rtp(rtp, rt->rt_best, current_inetgw)) {
       rt->rt_best = rtp;
@@ -510,7 +524,7 @@ struct rt_path *
 olsr_insert_routing_table(union olsr_ip_addr *dst, int plen,
                           union olsr_ip_addr *originator, int origin)
 {
-#if !defined(NODEBUG) && defined(DEBUG)
+#ifdef DEBUG
   struct ipaddr_str dstbuf, origbuf;
 #endif
   struct tc_entry *tc;
@@ -525,16 +539,9 @@ olsr_insert_routing_table(union olsr_ip_addr *dst, int plen,
     return NULL;
   }
 
-#ifdef DEBUG
-  OLSR_PRINTF(1, "RIB: add prefix %s/%u from %s\n",
-              olsr_ip_to_string(&dstbuf, dst), plen,
-              olsr_ip_to_string(&origbuf, originator));
-#endif
-
   /*
-   * For internal routes the tc_entry must already exist.
-   * For all other routes we may create it as an edgeless
-   * hookup point. If so he tc_entry has no edges it will not
+   * For all routes we use the tc_entry as an hookup point.
+   * If the tc_entry is disconnected, i.e. has no edges it will not
    * be explored during SPF run.
    */
   tc = olsr_locate_tc_entry(originator);
@@ -556,11 +563,17 @@ olsr_insert_routing_table(union olsr_ip_addr *dst, int plen,
       return NULL;
     }
 
+#ifdef DEBUG
+    OLSR_PRINTF(1, "RIB: add prefix %s/%u from %s\n",
+                olsr_ip_to_string(&dstbuf, dst), plen,
+                olsr_ip_to_string(&origbuf, originator));
+#endif
+
     /* overload the hna change bit for flagging a prefix change */
     changes_hna = OLSR_TRUE;
 
   } else {
-    rtp = node->data;
+    rtp = rtp_prefix_tree2rtp(node);
   }
 
   return rtp;
@@ -573,8 +586,8 @@ void
 olsr_delete_routing_table(union olsr_ip_addr *dst, int plen,
                           union olsr_ip_addr *originator)
 {
-#if !defined(NODEBUG) && defined(DEBUG)
-  struct ipaddr_str buf;
+#ifdef DEBUG
+  struct ipaddr_str dstbuf, origbuf;
 #endif
 
   struct tc_entry *tc;
@@ -589,12 +602,6 @@ olsr_delete_routing_table(union olsr_ip_addr *dst, int plen,
     return;
   }
 
-#ifdef DEBUG
-  OLSR_PRINTF(1, "RIB: del prefix %s/%u from %s\n",
-              olsr_ip_to_string(&buf, dst), plen,
-              olsr_ip_to_string(&buf, originator));
-#endif
-
   tc = olsr_lookup_tc_entry(originator);
   if (!tc) {
     return;
@@ -609,8 +616,14 @@ olsr_delete_routing_table(union olsr_ip_addr *dst, int plen,
   node = avl_find(&tc->prefix_tree, &prefix);
 
   if (node) {
-    rtp = node->data;
-    olsr_free_rt_path(rtp);
+    rtp = rtp_prefix_tree2rtp(node);
+    olsr_delete_rt_path(rtp);
+
+#ifdef DEBUG
+    OLSR_PRINTF(1, "RIB: del prefix %s/%u from %s\n",
+                olsr_ip_to_string(&dstbuf, dst), plen,
+                olsr_ip_to_string(&origbuf, originator));
+#endif
 
     /* overload the hna change bit for flagging a prefix change */
     changes_hna = OLSR_TRUE;
@@ -644,15 +657,16 @@ olsr_rtp_to_string(const struct rt_path *rtp)
   static char buff[128];
   struct ipaddr_str prefixstr, origstr, gwstr;
   struct rt_entry *rt = rtp->rtp_rt;
-
+  struct lqtextbuffer lqbuffer;
+  
   snprintf(buff, sizeof(buff),
            "%s/%u from %s via %s, "
-           "etx %.3f, metric %u, v %u",
+           "cost %s, metric %u, v %u",
            olsr_ip_to_string(&prefixstr, &rt->rt_dst.prefix),
            rt->rt_dst.prefix_len,
            olsr_ip_to_string(&origstr, &rtp->rtp_originator),
            olsr_ip_to_string(&gwstr, &rtp->rtp_nexthop.gateway),
-           rtp->rtp_metric.etx,
+           get_linkcost_text(rtp->rtp_metric.cost, OLSR_TRUE, &lqbuffer),
            rtp->rtp_metric.hops,
            rtp->rtp_version);
 
@@ -664,42 +678,45 @@ olsr_rtp_to_string(const struct rt_path *rtp)
  *
  */
 void
-olsr_print_routing_table(const struct avl_tree *tree)
+olsr_print_routing_table(struct avl_tree *tree)
 {
-  const struct avl_node *rt_tree_node;
+#ifndef NODEBUG
+  /* The whole function makes no sense without it. */
+  struct avl_node *rt_tree_node;
+  struct lqtextbuffer lqbuffer;
+  
+  OLSR_PRINTF(6, "ROUTING TABLE\n");
 
-#ifdef DEBUG
-  printf("ROUTING TABLE\n");
-#endif
-
-  for (rt_tree_node = avl_walk_first_c(tree);
+  for (rt_tree_node = avl_walk_first(tree);
        rt_tree_node != NULL;
-       rt_tree_node = avl_walk_next_c(rt_tree_node)) {
-    const struct avl_node *rtp_tree_node;
+       rt_tree_node = avl_walk_next(rt_tree_node)) {
+    struct avl_node *rtp_tree_node;
     struct ipaddr_str prefixstr, origstr, gwstr;
-    const struct rt_entry * const rt = rt_tree_node->data;
+    struct rt_entry *rt = rt_tree2rt(rt_tree_node);
 
     /* first the route entry */
-    printf("%s/%u, via %s, best-originator %s\n",
+    OLSR_PRINTF(6, "%s/%u, via %s, best-originator %s\n",
            olsr_ip_to_string(&prefixstr, &rt->rt_dst.prefix),
            rt->rt_dst.prefix_len,
            olsr_ip_to_string(&origstr, &rt->rt_nexthop.gateway),
            olsr_ip_to_string(&gwstr, &rt->rt_best->rtp_originator));
 
     /* walk the per-originator path tree of routes */
-    for (rtp_tree_node = avl_walk_first_c(&rt->rt_path_tree);
+    for (rtp_tree_node = avl_walk_first(&rt->rt_path_tree);
          rtp_tree_node != NULL;
-         rtp_tree_node = avl_walk_next_c(rtp_tree_node)) {
-      const struct rt_path * const rtp = rtp_tree_node->data;
-      printf("\tfrom %s, etx %.3f, metric %u, via %s, %s, v %u\n",
+         rtp_tree_node = avl_walk_next(rtp_tree_node)) {
+      struct rt_path *rtp = rtp_tree2rtp(rtp_tree_node);
+      OLSR_PRINTF(6, "\tfrom %s, cost %s, metric %u, via %s, %s, v %u\n",
              olsr_ip_to_string(&origstr, &rtp->rtp_originator),
-             rtp->rtp_metric.etx,
+             get_linkcost_text(rtp->rtp_metric.cost, OLSR_TRUE, &lqbuffer),
              rtp->rtp_metric.hops,
              olsr_ip_to_string(&gwstr, &rtp->rtp_nexthop.gateway),
              if_ifwithindex_name(rt->rt_nexthop.iif_index),
              rtp->rtp_version);    
     }
   }
+#endif
+  tree = NULL; /* squelch compiler warnings */
 }
 
 /*
