@@ -36,7 +36,6 @@
  * to the project. For more information see the website or contact
  * the copyright holders.
  *
- * $Id: compat.c,v 1.16 2007/07/15 21:09:38 bernd67 Exp $
  */
 
 /*
@@ -62,6 +61,8 @@
 #include <ctype.h>
 #include <dlfcn.h>
 #include <io.h>
+#include <arpa/inet.h>
+
 #include "defs.h"
 
 void PError(char *Str);
@@ -88,7 +89,8 @@ unsigned int random(void)
 
 int getpid(void)
 {
-  return (int)GetCurrentThread();
+  HANDLE h = GetCurrentThread();
+  return (int)h;
 }
 
 int nanosleep(struct timespec *Req, struct timespec *Rem)
@@ -148,7 +150,7 @@ char *StrError(unsigned int ErrNo)
 
   if (WideCharToMultiByte(CP_ACP, 0, WideMsg, -1, Msg, sizeof (Msg),
                           NULL, NULL) == 0)
-    strcpy(Msg, "[cannot convert string]");
+  strscpy(Msg, "[cannot convert string]", sizeof(Msg));
 #endif
 
   return Msg;
@@ -184,7 +186,7 @@ int dlclose(void *Handle)
   return 0;
 }
 
-void *dlsym(void *Handle, char *Name)
+void *dlsym(void *Handle, const char *Name)
 {
 #if !defined WINCE
   return GetProcAddress((HMODULE)Handle, Name);
@@ -387,7 +389,7 @@ static char *inet_ntop4(const unsigned char *src, char *dst, int size)
   if (sprintf(tmp, fmt, src[0], src[1], src[2], src[3]) > size)
     return (NULL);
 
-  return strcpy(dst, tmp);
+  return strscpy(dst, tmp, size);
 }
 
 static char *inet_ntop6(const unsigned char *src, char *dst, int size)
@@ -475,7 +477,7 @@ static char *inet_ntop6(const unsigned char *src, char *dst, int size)
   if ((tp - tmp) > size)
     return (NULL);
 
-  return strcpy(dst, tmp);
+  return strscpy(dst, tmp, size);
 }
 
 char *inet_ntop(int af, const void *src, char *dst, int size)
@@ -531,7 +533,7 @@ int write(int fd, const void *buf, unsigned int count)
 {
   size_t written = 0;
   while (written < count) {
-    ssize_t rc = send(fd, buf+written, min(count-written, CHUNK_SIZE), 0);
+    ssize_t rc = send(fd, (const unsigned char*)buf+written, min(count-written, CHUNK_SIZE), 0);
     if (rc <= 0) {
       break;
     }
