@@ -1,33 +1,34 @@
+
 /*
  * The olsr.org Optimized Link-State Routing daemon (olsrd)
  * Copyright (c) 2004, Thomas Lopatic (thomas@lopatic.de)
  * All rights reserved.
  *
- * Redistribution and use in source and binary forms, with or without 
- * modification, are permitted provided that the following conditions 
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
  * are met:
  *
- * * Redistributions of source code must retain the above copyright 
+ * * Redistributions of source code must retain the above copyright
  *   notice, this list of conditions and the following disclaimer.
- * * Redistributions in binary form must reproduce the above copyright 
- *   notice, this list of conditions and the following disclaimer in 
- *   the documentation and/or other materials provided with the 
+ * * Redistributions in binary form must reproduce the above copyright
+ *   notice, this list of conditions and the following disclaimer in
+ *   the documentation and/or other materials provided with the
  *   distribution.
- * * Neither the name of olsr.org, olsrd nor the names of its 
- *   contributors may be used to endorse or promote products derived 
+ * * Neither the name of olsr.org, olsrd nor the names of its
+ *   contributors may be used to endorse or promote products derived
  *   from this software without specific prior written permission.
  *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
- * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
- * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
- * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
- * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
- * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
- * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
- * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
- * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+ * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
+ * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
+ * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
+ * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
+ * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
+ * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
+ * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
+ * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
+ * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
  * POSSIBILITY OF SUCH DAMAGE.
  *
  * Visit http://www.olsr.org for more information.
@@ -57,11 +58,9 @@
 
 #include <arpa/inet.h>
 
-#define BUFSPACE  (127*1024)	/* max. input buffer size to request */
+#define BUFSPACE  (127*1024)    /* max. input buffer size to request */
 
-
-struct MibIpInterfaceRow
-{
+struct MibIpInterfaceRow {
   USHORT Family;
   ULONG64 InterfaceLuid;
   ULONG InterfaceIndex;
@@ -74,7 +73,7 @@ struct MibIpInterfaceRow
   BOOLEAN WeakHostSend;
   BOOLEAN WeakHostReceive;
   BOOLEAN UseAutomaticMetric;
-  BOOLEAN UseNeighborUnreachabilityDetection;   
+  BOOLEAN UseNeighborUnreachabilityDetection;
   BOOLEAN ManagedAddressConfigurationSupported;
   BOOLEAN OtherStatefulConfigurationSupported;
   BOOLEAN AdvertiseDefaultRoute;
@@ -88,26 +87,23 @@ struct MibIpInterfaceRow
   ULONG ZoneIndices[16];
   ULONG SitePrefixLength;
   ULONG Metric;
-  ULONG NlMtu;    
+  ULONG NlMtu;
   BOOLEAN Connected;
-  BOOLEAN SupportsWakeUpPatterns;   
+  BOOLEAN SupportsWakeUpPatterns;
   BOOLEAN SupportsNeighborDiscovery;
   BOOLEAN SupportsRouterDiscovery;
   ULONG ReachableTime;
   BYTE TransmitOffload;
-  BYTE ReceiveOffload; 
+  BYTE ReceiveOffload;
   BOOLEAN DisableDefaultRoutes;
 };
 
-typedef DWORD (__stdcall *GETIPINTERFACEENTRY)
-  (struct MibIpInterfaceRow *Row);
+typedef DWORD(__stdcall * GETIPINTERFACEENTRY) (struct MibIpInterfaceRow * Row);
 
-typedef DWORD (__stdcall *GETADAPTERSADDRESSES)
-  (ULONG Family, DWORD Flags, PVOID Reserved,
-   PIP_ADAPTER_ADDRESSES pAdapterAddresses, PULONG pOutBufLen);
+typedef DWORD(__stdcall * GETADAPTERSADDRESSES) (ULONG Family, DWORD Flags, PVOID Reserved, PIP_ADAPTER_ADDRESSES pAdapterAddresses,
+                                                 PULONG pOutBufLen);
 
-struct InterfaceInfo
-{
+struct InterfaceInfo {
   unsigned int Index;
   int Mtu;
   int Metric;
@@ -122,26 +118,28 @@ char *StrError(unsigned int ErrNo);
 
 void ListInterfaces(void);
 int GetIntInfo(struct InterfaceInfo *Info, char *Name);
-void RemoveInterface(struct olsr_if *IntConf);
 
 #define MAX_INTERFACES 100
 
 int __stdcall SignalHandler(unsigned long Signal);
 
-static unsigned long __stdcall SignalHandlerWrapper(void *Dummy __attribute__((unused)))
+static unsigned long __stdcall
+SignalHandlerWrapper(void *Dummy __attribute__ ((unused)))
 {
   SignalHandler(0);
   return 0;
 }
 
-static void CallSignalHandler(void)
+static void
+CallSignalHandler(void)
 {
   unsigned long ThreadId;
 
   CreateThread(NULL, 0, SignalHandlerWrapper, NULL, 0, &ThreadId);
 }
 
-static void MiniIndexToIntName(char *String, int MiniIndex)
+static void
+MiniIndexToIntName(char *String, int MiniIndex)
 {
   const char *HexDigits = "0123456789abcdef";
 
@@ -154,20 +152,19 @@ static void MiniIndexToIntName(char *String, int MiniIndex)
   String[4] = 0;
 }
 
-static int IntNameToMiniIndex(int *MiniIndex, char *String)
+static int
+IntNameToMiniIndex(int *MiniIndex, char *String)
 {
   const char *HexDigits = "0123456789abcdef";
   int i, k;
   char ch;
 
-  if ((String[0] != 'i' && String[0] != 'I') ||
-      (String[1] != 'f' && String[1] != 'F'))
+  if ((String[0] != 'i' && String[0] != 'I') || (String[1] != 'f' && String[1] != 'F'))
     return -1;
 
   *MiniIndex = 0;
 
-  for (i = 2; i < 4; i++)
-  {
+  for (i = 2; i < 4; i++) {
     ch = String[i];
 
     if (ch >= 'A' && ch <= 'F')
@@ -184,7 +181,8 @@ static int IntNameToMiniIndex(int *MiniIndex, char *String)
   return 0;
 }
 
-static int FriendlyNameToMiniIndex(int *MiniIndex, char *String)
+static int
+FriendlyNameToMiniIndex(int *MiniIndex, char *String)
 {
   unsigned long BuffLen;
   unsigned long Res;
@@ -192,38 +190,34 @@ static int FriendlyNameToMiniIndex(int *MiniIndex, char *String)
   char FriendlyName[MAX_INTERFACE_NAME_LEN];
   HMODULE h;
   GETADAPTERSADDRESSES pfGetAdaptersAddresses;
-  
+
   h = LoadLibrary("iphlpapi.dll");
 
-  if (h == NULL)
-  {
+  if (h == NULL) {
     fprintf(stderr, "LoadLibrary() = %08lx", GetLastError());
     return -1;
   }
 
   pfGetAdaptersAddresses = (GETADAPTERSADDRESSES) GetProcAddress(h, "GetAdaptersAddresses");
 
-  if (pfGetAdaptersAddresses == NULL)
-  {
+  if (pfGetAdaptersAddresses == NULL) {
     fprintf(stderr, "Unable to use adapter friendly name (GetProcAddress() = %08lx)\n", GetLastError());
     return -1;
   }
-  
-  BuffLen = sizeof (AdAddr);
+
+  BuffLen = sizeof(AdAddr);
 
   Res = pfGetAdaptersAddresses(AF_INET, 0, NULL, AdAddr, &BuffLen);
 
-  if (Res != NO_ERROR)
-  {  
+  if (Res != NO_ERROR) {
     fprintf(stderr, "GetAdaptersAddresses() = %08lx", GetLastError());
     return -1;
   }
 
-  for (WalkerAddr = AdAddr; WalkerAddr != NULL; WalkerAddr = WalkerAddr->Next)
-  {
+  for (WalkerAddr = AdAddr; WalkerAddr != NULL; WalkerAddr = WalkerAddr->Next) {
     OLSR_PRINTF(5, "Index = %08x - ", (int)WalkerAddr->IfIndex);
 
-    wcstombs(FriendlyName, WalkerAddr->FriendlyName, MAX_INTERFACE_NAME_LEN); 
+    wcstombs(FriendlyName, WalkerAddr->FriendlyName, MAX_INTERFACE_NAME_LEN);
 
     OLSR_PRINTF(5, "Friendly name = %s\n", FriendlyName);
 
@@ -231,19 +225,21 @@ static int FriendlyNameToMiniIndex(int *MiniIndex, char *String)
       break;
   }
 
-  if (WalkerAddr == NULL)
-  {
+  if (WalkerAddr == NULL) {
     fprintf(stderr, "No such interface: %s!\n", String);
     return -1;
   }
 
   *MiniIndex = WalkerAddr->IfIndex & 255;
+
+  return 0;
 }
 
-int GetIntInfo(struct InterfaceInfo *Info, char *Name)
+int
+GetIntInfo(struct InterfaceInfo *Info, char *Name)
 {
   int MiniIndex;
-  unsigned char Buff[MAX_INTERFACES * sizeof (MIB_IFROW) + 4];
+  unsigned char Buff[MAX_INTERFACES * sizeof(MIB_IFROW) + 4];
   MIB_IFTABLE *IfTable;
   unsigned long BuffLen;
   unsigned long Res;
@@ -253,91 +249,77 @@ int GetIntInfo(struct InterfaceInfo *Info, char *Name)
   struct MibIpInterfaceRow Row;
   GETIPINTERFACEENTRY InterfaceEntry;
 
-  if (olsr_cnf->ip_version == AF_INET6)
-  {
+  if (olsr_cnf->ip_version == AF_INET6) {
     fprintf(stderr, "IPv6 not supported by GetIntInfo()!\n");
     return -1;
   }
 
-  if ((Name[0] != 'i' && Name[0] != 'I') ||
-      (Name[1] != 'f' && Name[1] != 'F'))
-  {
-    if (FriendlyNameToMiniIndex(&MiniIndex, Name) < 0)
-    {
+  if ((Name[0] != 'i' && Name[0] != 'I') || (Name[1] != 'f' && Name[1] != 'F')) {
+    if (FriendlyNameToMiniIndex(&MiniIndex, Name) < 0) {
       fprintf(stderr, "No such interface: %s!\n", Name);
       return -1;
     }
   }
 
-  else
-  {
-    if (IntNameToMiniIndex(&MiniIndex, Name) < 0)
-    {
+  else {
+    if (IntNameToMiniIndex(&MiniIndex, Name) < 0) {
       fprintf(stderr, "No such interface: %s!\n", Name);
       return -1;
     }
   }
 
-  IfTable = (MIB_IFTABLE *)Buff;
+  IfTable = (MIB_IFTABLE *) Buff;
 
-  BuffLen = sizeof (Buff);
+  BuffLen = sizeof(Buff);
 
   Res = GetIfTable(IfTable, &BuffLen, FALSE);
 
-  if (Res != NO_ERROR)
-  {
+  if (Res != NO_ERROR) {
     fprintf(stderr, "GetIfTable() = %08lx, %s", Res, StrError(Res));
     return -1;
   }
 
-  for (TabIdx = 0; TabIdx < (int)IfTable->dwNumEntries; TabIdx++)
-  {
+  for (TabIdx = 0; TabIdx < (int)IfTable->dwNumEntries; TabIdx++) {
     OLSR_PRINTF(5, "Index = %08x\n", (int)IfTable->table[TabIdx].dwIndex);
 
     if ((int)(IfTable->table[TabIdx].dwIndex & 255) == MiniIndex)
       break;
   }
 
-  if (TabIdx == (int)IfTable->dwNumEntries)
-  {
+  if (TabIdx == (int)IfTable->dwNumEntries) {
     fprintf(stderr, "No such interface: %s!\n", Name);
     return -1;
   }
-    
+
   Info->Index = IfTable->table[TabIdx].dwIndex;
   Info->Mtu = (int)IfTable->table[TabIdx].dwMtu;
 
-  Info->Mtu -= (olsr_cnf->ip_version == AF_INET6) ?
-    UDP_IPV6_HDRSIZE : UDP_IPV4_HDRSIZE;
+  Info->Mtu -= (olsr_cnf->ip_version == AF_INET6) ? UDP_IPV6_HDRSIZE : UDP_IPV4_HDRSIZE;
 
   Lib = LoadLibrary("iphlpapi.dll");
 
-  if (Lib == NULL)
-  {
+  if (Lib == NULL) {
     fprintf(stderr, "Cannot load iphlpapi.dll: %08lx\n", GetLastError());
     return -1;
   }
 
-  InterfaceEntry = (GETIPINTERFACEENTRY)GetProcAddress(Lib, "GetIpInterfaceEntry");
+  InterfaceEntry = (GETIPINTERFACEENTRY) GetProcAddress(Lib, "GetIpInterfaceEntry");
 
-  if (InterfaceEntry == NULL)
-  {
+  if (InterfaceEntry == NULL) {
     OLSR_PRINTF(5, "Not running on Vista - setting interface metric to 0.\n");
 
     Info->Metric = 0;
   }
 
-  else
-  {
-    memset(&Row, 0, sizeof (struct MibIpInterfaceRow));
+  else {
+    memset(&Row, 0, sizeof(struct MibIpInterfaceRow));
 
     Row.Family = AF_INET;
     Row.InterfaceIndex = Info->Index;
 
     Res = InterfaceEntry(&Row);
 
-    if (Res != NO_ERROR)
-    {
+    if (Res != NO_ERROR) {
       fprintf(stderr, "GetIpInterfaceEntry() = %08lx", Res);
       FreeLibrary(Lib);
       return -1;
@@ -350,27 +332,23 @@ int GetIntInfo(struct InterfaceInfo *Info, char *Name)
 
   FreeLibrary(Lib);
 
-  BuffLen = sizeof (AdInfo);
+  BuffLen = sizeof(AdInfo);
 
   Res = GetAdaptersInfo(AdInfo, &BuffLen);
 
-  if (Res != NO_ERROR)
-  {
-    fprintf(stderr, "GetAdaptersInfo() = %08lx, %s", GetLastError(),
-            StrError(Res));
+  if (Res != NO_ERROR) {
+    fprintf(stderr, "GetAdaptersInfo() = %08lx, %s", GetLastError(), StrError(Res));
     return -1;
   }
 
-  for (Walker = AdInfo; Walker != NULL; Walker = Walker->Next)
-  {
+  for (Walker = AdInfo; Walker != NULL; Walker = Walker->Next) {
     OLSR_PRINTF(5, "Index = %08x\n", (int)Walker->Index);
 
     if ((int)(Walker->Index & 255) == MiniIndex)
       break;
   }
 
-  if (Walker == NULL)
-  {
+  if (Walker == NULL) {
     fprintf(stderr, "No such interface: %s!\n", Name);
     return -1;
   }
@@ -380,12 +358,10 @@ int GetIntInfo(struct InterfaceInfo *Info, char *Name)
 
   Info->Broad = Info->Addr | ~Info->Mask;
 
-  strcpy(Info->Guid, Walker->AdapterName);
+  strscpy(Info->Guid, Walker->AdapterName, sizeof(Info->Guid));
 
-  if ((IfTable->table[TabIdx].dwOperStatus != MIB_IF_OPER_STATUS_CONNECTED &&
-      IfTable->table[TabIdx].dwOperStatus != MIB_IF_OPER_STATUS_OPERATIONAL) ||
-      Info->Addr == 0)
-  {
+  if ((IfTable->table[TabIdx].dwOperStatus != MIB_IF_OPER_STATUS_CONNECTED
+       && IfTable->table[TabIdx].dwOperStatus != MIB_IF_OPER_STATUS_OPERATIONAL) || Info->Addr == 0) {
     OLSR_PRINTF(3, "Interface %s not up!\n", Name);
     return -1;
   }
@@ -401,7 +377,8 @@ int GetIntInfo(struct InterfaceInfo *Info, char *Name)
 #define IOCTL_NDIS_QUERY_GLOBAL_STATS 0x00170002
 #endif
 
-static int IsWireless(char *IntName)
+static int
+IsWireless(char *IntName)
 {
 #if !defined WINCE
   struct InterfaceInfo Info;
@@ -420,16 +397,13 @@ static int IsWireless(char *IntName)
   DevName[2] = '.';
   DevName[3] = '\\';
 
-  strcpy(DevName + 4, Info.Guid);
+  strscpy(DevName + 4, Info.Guid, sizeof(DevName) - 4);
 
   OLSR_PRINTF(5, "Checking whether interface %s is wireless.\n", DevName);
 
-  DevHand = CreateFile(DevName, GENERIC_READ,
-                       FILE_SHARE_READ | FILE_SHARE_WRITE, NULL, OPEN_EXISTING,
-                       FILE_ATTRIBUTE_NORMAL, NULL);
+  DevHand = CreateFile(DevName, GENERIC_READ, FILE_SHARE_READ | FILE_SHARE_WRITE, NULL, OPEN_EXISTING, FILE_ATTRIBUTE_NORMAL, NULL);
 
-  if (DevHand == INVALID_HANDLE_VALUE)
-  {
+  if (DevHand == INVALID_HANDLE_VALUE) {
     ErrNo = GetLastError();
 
     OLSR_PRINTF(5, "CreateFile() = %08x, %s\n", ErrNo, StrError(ErrNo));
@@ -438,17 +412,12 @@ static int IsWireless(char *IntName)
 
   Oid = OID_802_11_CONFIGURATION;
 
-  if (!DeviceIoControl(DevHand, IOCTL_NDIS_QUERY_GLOBAL_STATS,
-                       &Oid, sizeof (Oid),
-                       OutBuff, sizeof (OutBuff),
-                       &OutBytes, NULL))
-  {
+  if (!DeviceIoControl(DevHand, IOCTL_NDIS_QUERY_GLOBAL_STATS, &Oid, sizeof(Oid), OutBuff, sizeof(OutBuff), &OutBytes, NULL)) {
     ErrNo = GetLastError();
 
     CloseHandle(DevHand);
 
-    if (ErrNo == ERROR_GEN_FAILURE || ErrNo == ERROR_INVALID_PARAMETER)
-    {
+    if (ErrNo == ERROR_GEN_FAILURE || ErrNo == ERROR_INVALID_PARAMETER) {
       OLSR_PRINTF(5, "OID not supported. Device probably not wireless.\n");
       return 0;
     }
@@ -462,7 +431,8 @@ static int IsWireless(char *IntName)
   return 1;
 }
 
-void ListInterfaces(void)
+void
+ListInterfaces(void)
 {
   IP_ADAPTER_INFO AdInfo[MAX_INTERFACES], *Walker;
   unsigned long AdInfoLen;
@@ -470,31 +440,27 @@ void ListInterfaces(void)
   IP_ADDR_STRING *Walker2;
   unsigned long Res;
   int IsWlan;
-  
-  if (olsr_cnf->ip_version == AF_INET6)
-  {
+
+  if (olsr_cnf->ip_version == AF_INET6) {
     fprintf(stderr, "IPv6 not supported by ListInterfaces()!\n");
     return;
   }
 
-  AdInfoLen = sizeof (AdInfo);
+  AdInfoLen = sizeof(AdInfo);
 
   Res = GetAdaptersInfo(AdInfo, &AdInfoLen);
 
-  if (Res == ERROR_NO_DATA)
-  {
+  if (Res == ERROR_NO_DATA) {
     printf("No interfaces detected.\n");
     return;
   }
-  
-  if (Res != NO_ERROR)
-  {
+
+  if (Res != NO_ERROR) {
     fprintf(stderr, "GetAdaptersInfo() = %08lx, %s", Res, StrError(Res));
     return;
   }
 
-  for (Walker = AdInfo; Walker != NULL; Walker = Walker->Next)
-  {
+  for (Walker = AdInfo; Walker != NULL; Walker = Walker->Next) {
     OLSR_PRINTF(5, "Index = %08x\n", (int)Walker->Index);
 
     MiniIndexToIntName(IntName, Walker->Index);
@@ -512,79 +478,56 @@ void ListInterfaces(void)
     else
       printf("+");
 
-    for (Walker2 = &Walker->IpAddressList; Walker2 != NULL;
-         Walker2 = Walker2->Next)
+    for (Walker2 = &Walker->IpAddressList; Walker2 != NULL; Walker2 = Walker2->Next)
       printf(" %s", Walker2->IpAddress.String);
 
     printf("\n");
   }
 }
 
-void RemoveInterface(struct olsr_if *IntConf)
+void
+RemoveInterface(struct olsr_if *IntConf, bool went_down)
 {
   struct interface *Int, *Prev;
 
   OLSR_PRINTF(1, "Removing interface %s.\n", IntConf->name);
-  
+
   Int = IntConf->interf;
 
   run_ifchg_cbs(Int, IFCHG_IF_ADD);
 
+  /*remove all routes*/
+  if (went_down) OLSR_PRINTF(1,"Hint: ifdown handling unimplemented");
+
   if (Int == ifnet)
     ifnet = Int->int_next;
 
-  else
-  {
+  else {
     for (Prev = ifnet; Prev->int_next != Int; Prev = Prev->int_next);
 
     Prev->int_next = Int->int_next;
   }
 
-  if(ipequal(&olsr_cnf->main_addr, &Int->ip_addr))
-  {
-    if(ifnet == NULL)
-    {
+  if (ipequal(&olsr_cnf->main_addr, &Int->ip_addr)) {
+    if (ifnet == NULL) {
       memset(&olsr_cnf->main_addr, 0, olsr_cnf->ipsize);
       OLSR_PRINTF(1, "Removed last interface. Cleared main address.\n");
     }
 
-    else
-    {
+    else {
       struct ipaddr_str buf;
       olsr_cnf->main_addr = ifnet->ip_addr;
       OLSR_PRINTF(1, "New main address: %s.\n", olsr_ip_to_string(&buf, &olsr_cnf->main_addr));
     }
   }
 
-  if (olsr_cnf->lq_level == 0)
-    {
-      olsr_remove_scheduler_event(&generate_hello, Int,
-                                  IntConf->cnf->hello_params.emission_interval,
-                                  0, NULL);
-
-      olsr_remove_scheduler_event(&generate_tc, Int,
-                                  IntConf->cnf->tc_params.emission_interval,
-                                  0, NULL);
-    }
-
-  else
-    {
-      olsr_remove_scheduler_event(&olsr_output_lq_hello, Int,
-                                  IntConf->cnf->hello_params.emission_interval,
-                                  0, NULL);
-
-      olsr_remove_scheduler_event(&olsr_output_lq_tc, Int,
-                                  IntConf->cnf->tc_params.emission_interval,
-                                  0, NULL);
-    }
-
-  olsr_remove_scheduler_event(&generate_mid, Int,
-                              IntConf->cnf->mid_params.emission_interval,
-                              0, NULL);
-
-  olsr_remove_scheduler_event(&generate_hna, Int,
-                              IntConf->cnf->hna_params.emission_interval,
-                              0, NULL);
+  /*
+   * Deregister functions for periodic message generation
+   */
+  olsr_stop_timer(Int->hello_gen_timer);
+  olsr_stop_timer(Int->tc_gen_timer);
+  olsr_stop_timer(Int->mid_gen_timer);
+  olsr_stop_timer(Int->hna_gen_timer);
 
   net_remove_buffer(Int);
 
@@ -597,36 +540,38 @@ void RemoveInterface(struct olsr_if *IntConf)
   free(Int->int_name);
   free(Int);
 
-  if (ifnet == NULL && !olsr_cnf->allow_no_interfaces)
-  {
+  if (ifnet == NULL && !olsr_cnf->allow_no_interfaces) {
     OLSR_PRINTF(1, "No more active interfaces - exiting.\n");
     olsr_cnf->exit_value = EXIT_FAILURE;
     CallSignalHandler();
   }
 }
 
-int add_hemu_if(struct olsr_if *iface)
+int
+add_hemu_if(struct olsr_if *iface)
 {
   struct interface *ifp;
   union olsr_ip_addr null_addr;
-  olsr_u32_t addr[4];
+  uint32_t addr[4];
   struct ipaddr_str buf;
+  size_t name_size;
 
-  if(!iface->host_emul)
+  if (!iface->host_emul)
     return -1;
 
-  ifp = olsr_malloc(sizeof (struct interface), "Interface update 2");
+  ifp = olsr_malloc(sizeof(struct interface), "Interface update 2");
 
-  memset(ifp, 0, sizeof (struct interface));
+  memset(ifp, 0, sizeof(struct interface));
 
-  iface->configured = OLSR_TRUE;
+  iface->configured = true;
   iface->interf = ifp;
 
-  ifp->is_hcif = OLSR_TRUE;
-  ifp->int_name = olsr_malloc(strlen("hcif01") + 1, "Interface update 3");
+  name_size = strlen("hcif01") + 1;
+  ifp->is_hcif = true;
+  ifp->int_name = olsr_malloc(name_size, "Interface update 3");
   ifp->int_metric = 0;
 
-  strcpy(ifp->int_name, "hcif01");
+  strscpy(ifp->int_name, "hcif01", name_size);
 
   OLSR_PRINTF(1, "Adding %s(host emulation):\n", ifp->int_name);
 
@@ -638,75 +583,66 @@ int add_hemu_if(struct olsr_if *iface)
   ifnet = ifp;
 
   memset(&null_addr, 0, olsr_cnf->ipsize);
-  if(ipequal(&null_addr, &olsr_cnf->main_addr))
-    {
-      olsr_cnf->main_addr = iface->hemu_ip;
-      OLSR_PRINTF(1, "New main address: %s\n", olsr_ip_to_string(&buf, &olsr_cnf->main_addr));
-    }
+  if (ipequal(&null_addr, &olsr_cnf->main_addr)) {
+    olsr_cnf->main_addr = iface->hemu_ip;
+    OLSR_PRINTF(1, "New main address: %s\n", olsr_ip_to_string(&buf, &olsr_cnf->main_addr));
+  }
 
   ifp->int_mtu = OLSR_DEFAULT_MTU;
 
-  ifp->int_mtu -= (olsr_cnf->ip_version == AF_INET6) ?
-    UDP_IPV6_HDRSIZE : UDP_IPV4_HDRSIZE;
+  ifp->int_mtu -= (olsr_cnf->ip_version == AF_INET6) ? UDP_IPV6_HDRSIZE : UDP_IPV4_HDRSIZE;
 
   /* Set up buffer */
   net_add_buffer(ifp);
 
+  if (olsr_cnf->ip_version == AF_INET) {
+    struct sockaddr_in sin;
 
-  if(olsr_cnf->ip_version == AF_INET)
-    {
-      struct sockaddr_in sin;
+    memset(&sin, 0, sizeof(sin));
 
-      memset(&sin, 0, sizeof(sin));
+    sin.sin_family = AF_INET;
+    sin.sin_addr.s_addr = htonl(INADDR_LOOPBACK);
+    sin.sin_port = htons(10150);
 
-      sin.sin_family = AF_INET;
-      sin.sin_addr.s_addr = htonl(INADDR_LOOPBACK);
-      sin.sin_port = htons(10150);
- 
-     /* IP version 4 */
-      ifp->ip_addr.v4 = iface->hemu_ip.v4;
+    /* IP version 4 */
+    ifp->ip_addr.v4 = iface->hemu_ip.v4;
 
-      memcpy(&((struct sockaddr_in *)&ifp->int_addr)->sin_addr, &iface->hemu_ip, olsr_cnf->ipsize);
-      
-      /*
-       *We create one socket for each interface and bind
-       *the socket to it. This to ensure that we can control
-       *on what interface the message is transmitted
-       */
-      
-      ifp->olsr_socket = gethemusocket(&sin);
-      
-      if (ifp->olsr_socket < 0)
-	{
-	  fprintf(stderr, "Could not initialize socket... exiting!\n\n");
-	  exit(1);
-	}
+    memcpy(&((struct sockaddr_in *)&ifp->int_addr)->sin_addr, &iface->hemu_ip, olsr_cnf->ipsize);
 
+    /*
+     *We create one socket for each interface and bind
+     *the socket to it. This to ensure that we can control
+     *on what interface the message is transmitted
+     */
+
+    ifp->olsr_socket = gethemusocket(&sin);
+
+    if (ifp->olsr_socket < 0) {
+      fprintf(stderr, "Could not initialize socket... exiting!\n\n");
+      exit(1);
     }
-  else
-    {
-      /* IP version 6 */
-      memcpy(&ifp->ip_addr, &iface->hemu_ip, olsr_cnf->ipsize);
 
-#if 0      
-      /*
-       *We create one socket for each interface and bind
-       *the socket to it. This to ensure that we can control
-       *on what interface the message is transmitted
-       */
-      
-      ifp->olsr_socket = gethcsocket6(&addrsock6, bufspace, ifp->int_name);
-      
-      join_mcast(ifp, ifp->olsr_socket);
-      
-      if (ifp->olsr_socket < 0)
-	{
-	  fprintf(stderr, "Could not initialize socket... exiting!\n\n");
-	  exit(1);
-	}
-      
+  } else {
+    /* IP version 6 */
+    memcpy(&ifp->ip_addr, &iface->hemu_ip, olsr_cnf->ipsize);
+
+#if 0
+    /*
+     *We create one socket for each interface and bind
+     *the socket to it. This to ensure that we can control
+     *on what interface the message is transmitted
+     */
+
+    ifp->olsr_socket = gethcsocket6(&addrsock6, bufspace, ifp->int_name);
+
+    join_mcast(ifp, ifp->olsr_socket);
+
+    if (ifp->olsr_socket < 0) {
+      fprintf(stderr, "Could not initialize socket... exiting!\n\n");
+      exit(1);
+    }
 #endif
-    }
+  }
 
   /* Send IP as first 4/16 bytes on socket */
   memcpy(addr, iface->hemu_ip.v6.s6_addr, olsr_cnf->ipsize);
@@ -715,74 +651,46 @@ int add_hemu_if(struct olsr_if *iface)
   addr[2] = htonl(addr[2]);
   addr[3] = htonl(addr[3]);
 
-  if(send(ifp->olsr_socket, (char *)addr, olsr_cnf->ipsize, 0) != (int)olsr_cnf->ipsize)
-    {
-      fprintf(stderr, "Error sending IP!");
-    }  
-  
+  if (send(ifp->olsr_socket, (char *)addr, olsr_cnf->ipsize, 0) != (int)olsr_cnf->ipsize) {
+    fprintf(stderr, "Error sending IP!");
+  }
+
   /* Register socket */
   add_olsr_socket(ifp->olsr_socket, &olsr_input_hostemu);
 
-
-  if (olsr_cnf->lq_level == 0)
-    {
-      olsr_register_scheduler_event(&generate_hello, 
-                                    ifp, 
-                                    iface->cnf->hello_params.emission_interval, 
-                                    0, 
-                                    NULL);
-      olsr_register_scheduler_event(&generate_tc, 
-                                    ifp, 
-                                    iface->cnf->tc_params.emission_interval,
-                                    0, 
-                                    NULL);
-    }
-
-  else
-    {
-      olsr_register_scheduler_event(&olsr_output_lq_hello, 
-                                    ifp, 
-                                    iface->cnf->hello_params.emission_interval, 
-                                    0, 
-                                    NULL);
-      olsr_register_scheduler_event(&olsr_output_lq_tc, 
-                                    ifp, 
-                                    iface->cnf->tc_params.emission_interval,
-                                    0, 
-                                    NULL);
-    }
-
-  olsr_register_scheduler_event(&generate_mid, 
-				ifp, 
-				iface->cnf->mid_params.emission_interval,
-				0, 
-				NULL);
-  olsr_register_scheduler_event(&generate_hna, 
-				ifp, 
-				iface->cnf->hna_params.emission_interval,
-				0, 
-				NULL);
-
-  /* Recalculate max jitter */
-
-  if((olsr_cnf->max_jitter == 0) || 
-     ((iface->cnf->hello_params.emission_interval / 4) < olsr_cnf->max_jitter))
-    olsr_cnf->max_jitter = iface->cnf->hello_params.emission_interval / 4;
+  /*
+   * Register functions for periodic message generation
+   */
+  ifp->hello_gen_timer =
+    olsr_start_timer(iface->cnf->hello_params.emission_interval * MSEC_PER_SEC, HELLO_JITTER, OLSR_TIMER_PERIODIC,
+                     olsr_cnf->lq_level == 0 ? &generate_hello : &olsr_output_lq_hello, ifp, hello_gen_timer_cookie->ci_id);
+  ifp->tc_gen_timer =
+    olsr_start_timer(iface->cnf->tc_params.emission_interval * MSEC_PER_SEC, TC_JITTER, OLSR_TIMER_PERIODIC,
+                     olsr_cnf->lq_level == 0 ? &generate_tc : &olsr_output_lq_tc, ifp, tc_gen_timer_cookie->ci_id);
+  ifp->mid_gen_timer =
+    olsr_start_timer(iface->cnf->mid_params.emission_interval * MSEC_PER_SEC, MID_JITTER, OLSR_TIMER_PERIODIC, &generate_mid, ifp,
+                     mid_gen_timer_cookie->ci_id);
+  ifp->hna_gen_timer =
+    olsr_start_timer(iface->cnf->hna_params.emission_interval * MSEC_PER_SEC, HNA_JITTER, OLSR_TIMER_PERIODIC, &generate_hna, ifp,
+                     hna_gen_timer_cookie->ci_id);
 
   /* Recalculate max topology hold time */
-  if(olsr_cnf->max_tc_vtime < iface->cnf->tc_params.emission_interval)
+  if (olsr_cnf->max_tc_vtime < iface->cnf->tc_params.emission_interval)
     olsr_cnf->max_tc_vtime = iface->cnf->tc_params.emission_interval;
 
-  ifp->hello_etime = iface->cnf->hello_params.emission_interval;
-  ifp->valtimes.hello = double_to_me(iface->cnf->hello_params.validity_time);
-  ifp->valtimes.tc = double_to_me(iface->cnf->tc_params.validity_time);
-  ifp->valtimes.mid = double_to_me(iface->cnf->mid_params.validity_time);
-  ifp->valtimes.hna = double_to_me(iface->cnf->hna_params.validity_time);
+  ifp->hello_etime = (olsr_reltime) (iface->cnf->hello_params.emission_interval * MSEC_PER_SEC);
+  ifp->valtimes.hello = reltime_to_me(iface->cnf->hello_params.validity_time * MSEC_PER_SEC);
+  ifp->valtimes.tc = reltime_to_me(iface->cnf->tc_params.validity_time * MSEC_PER_SEC);
+  ifp->valtimes.mid = reltime_to_me(iface->cnf->mid_params.validity_time * MSEC_PER_SEC);
+  ifp->valtimes.hna = reltime_to_me(iface->cnf->hna_params.validity_time * MSEC_PER_SEC);
+
+  ifp->mode = iface->cnf->mode;
 
   return 1;
 }
 
-int chk_if_changed(struct olsr_if *IntConf)
+int
+chk_if_changed(struct olsr_if *IntConf)
 {
   struct ipaddr_str buf;
   struct interface *Int;
@@ -792,21 +700,18 @@ int chk_if_changed(struct olsr_if *IntConf)
   union olsr_ip_addr OldVal, NewVal;
   struct sockaddr_in *AddrIn;
 
-  if (olsr_cnf->ip_version == AF_INET6)
-  {
+  if (olsr_cnf->ip_version == AF_INET6) {
     fprintf(stderr, "IPv6 not supported by chk_if_changed()!\n");
     return 0;
   }
-
 #ifdef DEBUG
   OLSR_PRINTF(3, "Checking if %s is set down or changed\n", IntConf->name);
 #endif
 
   Int = IntConf->interf;
 
-  if (GetIntInfo(&Info, IntConf->name) < 0)
-  {
-    RemoveInterface(IntConf);
+  if (GetIntInfo(&Info, IntConf->name) < 0) {
+    RemoveInterface(IntConf,false);
     return 1;
   }
 
@@ -817,8 +722,7 @@ int chk_if_changed(struct olsr_if *IntConf)
   if (IsWlan < 0)
     IsWlan = 1;
 
-  if (Int->is_wireless != IsWlan)
-  {
+  if (Int->is_wireless != IsWlan) {
     OLSR_PRINTF(1, "\tLAN/WLAN change: %d -> %d.\n", Int->is_wireless, IsWlan);
 
     Int->is_wireless = IsWlan;
@@ -832,10 +736,8 @@ int chk_if_changed(struct olsr_if *IntConf)
     Res = 1;
   }
 
-  if (Int->int_mtu != Info.Mtu)
-  {
-    OLSR_PRINTF(1, "\tMTU change: %d -> %d.\n", (int)Int->int_mtu,
-                Info.Mtu);
+  if (Int->int_mtu != Info.Mtu) {
+    OLSR_PRINTF(1, "\tMTU change: %d -> %d.\n", (int)Int->int_mtu, Info.Mtu);
 
     Int->int_mtu = Info.Mtu;
 
@@ -852,8 +754,7 @@ int chk_if_changed(struct olsr_if *IntConf)
   OLSR_PRINTF(3, "\tAddress: %s\n", olsr_ip_to_string(&buf, &NewVal));
 #endif
 
-  if (NewVal.v4.s_addr != OldVal.v4.s_addr)
-  {
+  if (NewVal.v4.s_addr != OldVal.v4.s_addr) {
     OLSR_PRINTF(1, "\tAddress change.\n");
     OLSR_PRINTF(1, "\tOld: %s\n", olsr_ip_to_string(&buf, &OldVal));
     OLSR_PRINTF(1, "\tNew: %s\n", olsr_ip_to_string(&buf, &NewVal));
@@ -866,8 +767,7 @@ int chk_if_changed(struct olsr_if *IntConf)
     AddrIn->sin_port = 0;
     AddrIn->sin_addr = NewVal.v4;
 
-    if (olsr_cnf->main_addr.v4.s_addr == OldVal.v4.s_addr)
-    {
+    if (olsr_cnf->main_addr.v4.s_addr == OldVal.v4.s_addr) {
       OLSR_PRINTF(1, "\tMain address change.\n");
 
       olsr_cnf->main_addr.v4 = NewVal.v4;
@@ -886,8 +786,7 @@ int chk_if_changed(struct olsr_if *IntConf)
   OLSR_PRINTF(3, "\tNetmask: %s\n", olsr_ip_to_string(&buf, &NewVal));
 #endif
 
-  if (NewVal.v4.s_addr != OldVal.v4.s_addr)
-  {
+  if (NewVal.v4.s_addr != OldVal.v4.s_addr) {
     OLSR_PRINTF(1, "\tNetmask change.\n");
     OLSR_PRINTF(1, "\tOld: %s\n", olsr_ip_to_string(&buf, &OldVal));
     OLSR_PRINTF(1, "\tNew: %s\n", olsr_ip_to_string(&buf, &NewVal));
@@ -911,8 +810,7 @@ int chk_if_changed(struct olsr_if *IntConf)
   OLSR_PRINTF(3, "\tBroadcast address: %s\n", olsr_ip_to_string(&buf, &NewVal));
 #endif
 
-  if (NewVal.v4.s_addr != OldVal.v4.s_addr)
-  {
+  if (NewVal.v4.s_addr != OldVal.v4.s_addr) {
     OLSR_PRINTF(1, "\tBroadcast address change.\n");
     OLSR_PRINTF(1, "\tOld: %s\n", olsr_ip_to_string(&buf, &OldVal));
     OLSR_PRINTF(1, "\tNew: %s\n", olsr_ip_to_string(&buf, &NewVal));
@@ -935,7 +833,8 @@ int chk_if_changed(struct olsr_if *IntConf)
   return Res;
 }
 
-int chk_if_up(struct olsr_if *IntConf, int DebugLevel __attribute__((unused)))
+int
+chk_if_up(struct olsr_if *IntConf, int DebugLevel __attribute__ ((unused)))
 {
   struct ipaddr_str buf;
   struct InterfaceInfo Info;
@@ -943,9 +842,9 @@ int chk_if_up(struct olsr_if *IntConf, int DebugLevel __attribute__((unused)))
   union olsr_ip_addr NullAddr;
   int IsWlan;
   struct sockaddr_in *AddrIn;
-  
-  if (olsr_cnf->ip_version == AF_INET6)
-  {
+  size_t name_size;
+
+  if (olsr_cnf->ip_version == AF_INET6) {
     fprintf(stderr, "IPv6 not supported by chk_if_up()!\n");
     return 0;
   }
@@ -953,9 +852,14 @@ int chk_if_up(struct olsr_if *IntConf, int DebugLevel __attribute__((unused)))
   if (GetIntInfo(&Info, IntConf->name) < 0)
     return 0;
 
-  New = olsr_malloc(sizeof (struct interface), "Interface 1");
+  New = olsr_malloc(sizeof(struct interface), "Interface 1");
 
   New->immediate_send_tc = (IntConf->cnf->tc_params.emission_interval < IntConf->cnf->hello_params.emission_interval);
+  if (olsr_cnf->max_jitter == 0) {
+    /* max_jitter determines the max time to store to-be-send-messages, correlated with random() */
+    olsr_cnf->max_jitter =
+      New->immediate_send_tc ? IntConf->cnf->tc_params.emission_interval : IntConf->cnf->hello_params.emission_interval;
+  }
 
   New->gen_properties = NULL;
 
@@ -982,12 +886,13 @@ int chk_if_up(struct olsr_if *IntConf, int DebugLevel __attribute__((unused)))
 
   New->int_flags = 0;
 
-  New->is_hcif = OLSR_FALSE;
+  New->is_hcif = false;
 
   New->int_mtu = Info.Mtu;
 
-  New->int_name = olsr_malloc(strlen (IntConf->name) + 1, "Interface 2");
-  strcpy(New->int_name, IntConf->name);
+  name_size = strlen(IntConf->name) + 1;
+  New->int_name = olsr_malloc(name_size, "Interface 2");
+  strscpy(New->int_name, IntConf->name, name_size);
 
   IsWlan = IsWireless(IntConf->name);
 
@@ -1004,26 +909,24 @@ int chk_if_up(struct olsr_if *IntConf, int DebugLevel __attribute__((unused)))
 
   New->olsr_seqnum = random() & 0xffff;
 
-  New->ttl_index = -32; /* For the first 32 TC's, fish-eye is disabled */
-    
-  OLSR_PRINTF(1, "\tInterface %s set up for use with index %d\n\n",
-              IntConf->name, New->if_index);
-      
+  New->ttl_index = -32;         /* For the first 32 TC's, fish-eye is disabled */
+
+  OLSR_PRINTF(1, "\tInterface %s set up for use with index %d\n\n", IntConf->name, New->if_index);
+
   OLSR_PRINTF(1, "\tMTU: %d\n", New->int_mtu);
-  OLSR_PRINTF(1, "\tAddress: %s\n", sockaddr4_to_string(&buf, (const struct sockaddr*)&New->int_addr));
-  OLSR_PRINTF(1, "\tNetmask: %s\n", sockaddr4_to_string(&buf, (const struct sockaddr*)&New->int_netmask));
-  OLSR_PRINTF(1, "\tBroadcast address: %s\n", sockaddr4_to_string(&buf, (const struct sockaddr*)&New->int_broadaddr));
+  OLSR_PRINTF(1, "\tAddress: %s\n", sockaddr4_to_string(&buf, (const struct sockaddr *)&New->int_addr));
+  OLSR_PRINTF(1, "\tNetmask: %s\n", sockaddr4_to_string(&buf, (const struct sockaddr *)&New->int_netmask));
+  OLSR_PRINTF(1, "\tBroadcast address: %s\n", sockaddr4_to_string(&buf, (const struct sockaddr *)&New->int_broadaddr));
 
   New->ip_addr.v4 = New->int_addr.sin_addr;
-      
+
   New->if_index = Info.Index;
 
   OLSR_PRINTF(3, "\tKernel index: %08x\n", New->if_index);
 
   New->olsr_socket = getsocket(BUFSPACE, New->int_name);
-      
-  if (New->olsr_socket < 0)
-  {
+
+  if (New->olsr_socket < 0) {
     fprintf(stderr, "Could not initialize socket... exiting!\n\n");
     exit(1);
   }
@@ -1037,65 +940,48 @@ int chk_if_up(struct olsr_if *IntConf, int DebugLevel __attribute__((unused)))
   IntConf->configured = 1;
 
   memset(&NullAddr, 0, olsr_cnf->ipsize);
-  
-  if(ipequal(&NullAddr, &olsr_cnf->main_addr))
-  {
+
+  if (ipequal(&NullAddr, &olsr_cnf->main_addr)) {
     olsr_cnf->main_addr = New->ip_addr;
     OLSR_PRINTF(1, "New main address: %s\n", olsr_ip_to_string(&buf, &olsr_cnf->main_addr));
   }
 
   net_add_buffer(New);
 
-  if (olsr_cnf->lq_level == 0)
-  {
-    olsr_register_scheduler_event(&generate_hello, New,
-                                  IntConf->cnf->hello_params.emission_interval,
-                                  0, NULL);
+  /*
+   * Register functions for periodic message generation
+   */
+  New->hello_gen_timer =
+    olsr_start_timer(IntConf->cnf->hello_params.emission_interval * MSEC_PER_SEC, HELLO_JITTER, OLSR_TIMER_PERIODIC,
+                     olsr_cnf->lq_level == 0 ? &generate_hello : &olsr_output_lq_hello, New, hello_gen_timer_cookie->ci_id);
+  New->tc_gen_timer =
+    olsr_start_timer(IntConf->cnf->tc_params.emission_interval * MSEC_PER_SEC, TC_JITTER, OLSR_TIMER_PERIODIC,
+                     olsr_cnf->lq_level == 0 ? &generate_tc : &olsr_output_lq_tc, New, tc_gen_timer_cookie->ci_id);
+  New->mid_gen_timer =
+    olsr_start_timer(IntConf->cnf->mid_params.emission_interval * MSEC_PER_SEC, MID_JITTER, OLSR_TIMER_PERIODIC, &generate_mid, New,
+                     mid_gen_timer_cookie->ci_id);
+  New->hna_gen_timer =
+    olsr_start_timer(IntConf->cnf->hna_params.emission_interval * MSEC_PER_SEC, HNA_JITTER, OLSR_TIMER_PERIODIC, &generate_hna, New,
+                     hna_gen_timer_cookie->ci_id);
 
-    olsr_register_scheduler_event(&generate_tc, New,
-                                  IntConf->cnf->tc_params.emission_interval,
-                                  0, NULL);
-  }
-
-  else
-  {
-    olsr_register_scheduler_event(&olsr_output_lq_hello, New,
-                                  IntConf->cnf->hello_params.emission_interval,
-                                  0, NULL);
-
-    olsr_register_scheduler_event(&olsr_output_lq_tc, New,
-                                  IntConf->cnf->tc_params.emission_interval,
-                                  0, NULL);
-  }
-
-  olsr_register_scheduler_event(&generate_mid, New,
-                                IntConf->cnf->mid_params.emission_interval,
-                                0, NULL);
-
-  olsr_register_scheduler_event(&generate_hna, New,
-                                IntConf->cnf->hna_params.emission_interval,
-                                0, NULL);
-
-  if(olsr_cnf->max_jitter == 0 ||
-     IntConf->cnf->hello_params.emission_interval / 4 < olsr_cnf->max_jitter)
-    olsr_cnf->max_jitter = IntConf->cnf->hello_params.emission_interval / 4;
-
-  if(olsr_cnf->max_tc_vtime < IntConf->cnf->tc_params.emission_interval)
+  if (olsr_cnf->max_tc_vtime < IntConf->cnf->tc_params.emission_interval)
     olsr_cnf->max_tc_vtime = IntConf->cnf->tc_params.emission_interval;
 
-  New->hello_etime = IntConf->cnf->hello_params.emission_interval;
+  New->hello_etime = (olsr_reltime) (IntConf->cnf->hello_params.emission_interval * MSEC_PER_SEC);
+  New->valtimes.hello = reltime_to_me(IntConf->cnf->hello_params.validity_time * MSEC_PER_SEC);
+  New->valtimes.tc = reltime_to_me(IntConf->cnf->tc_params.validity_time * MSEC_PER_SEC);
+  New->valtimes.mid = reltime_to_me(IntConf->cnf->mid_params.validity_time * MSEC_PER_SEC);
+  New->valtimes.hna = reltime_to_me(IntConf->cnf->hna_params.validity_time * MSEC_PER_SEC);
 
-  New->valtimes.hello = double_to_me(IntConf->cnf->hello_params.validity_time);
-  New->valtimes.tc = double_to_me(IntConf->cnf->tc_params.validity_time);
-  New->valtimes.mid = double_to_me(IntConf->cnf->mid_params.validity_time);
-  New->valtimes.hna = double_to_me(IntConf->cnf->hna_params.validity_time);
+  New->mode = iface->cnf->mode;
 
   run_ifchg_cbs(New, IFCHG_IF_ADD);
 
   return 1;
 }
 
-void check_interface_updates(void *dummy __attribute__((unused)))
+void
+check_interface_updates(void *dummy __attribute__ ((unused)))
 {
   struct olsr_if *IntConf;
 
@@ -1103,18 +989,24 @@ void check_interface_updates(void *dummy __attribute__((unused)))
   OLSR_PRINTF(3, "Checking for updates in the interface set\n");
 #endif
 
-  for(IntConf = olsr_cnf->interfaces; IntConf != NULL; IntConf = IntConf->next)
-  {
-    if(IntConf->host_emul)
+  for (IntConf = olsr_cnf->interfaces; IntConf != NULL; IntConf = IntConf->next) {
+    if (IntConf->host_emul)
       continue;
-      
-    if(olsr_cnf->host_emul) /* XXX: TEMPORARY! */
+
+    if (olsr_cnf->host_emul)    /* XXX: TEMPORARY! */
       continue;
- 
-    if(IntConf->configured)    
+
+    if (IntConf->configured)
       chk_if_changed(IntConf);
 
     else
       chk_if_up(IntConf, 3);
   }
 }
+
+/*
+ * Local Variables:
+ * c-basic-offset: 2
+ * indent-tabs-mode: nil
+ * End:
+ */
